package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(``P`!````U)@$"#0```!$S@```````#0`(``)
M`"@`'``;``8````T````-(`$"#2`!`@@`0``(`$```4````$`````P```%0!
M``!4@00(5($$"!,````3````!`````$````!``````````"`!`@`@`0(Q&<`
M`,1G```%`````!````$````$;P``!/\$"`3_!`@`7@``C&X```8`````$```
M`@```!AO```8_P0(&/\$"-@```#8````!@````0````$````:`$``&B!!`AH
M@00(1````$0````$````!````%#E=&2080``D.$$")#A!`C\````_`````0`
M```$````4>5T9```````````````````````````!@````0```!2Y71D!&\`
M``3_!`@$_P0(_````/P````$`````0```"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!`````!````1TY5```````"````!@````\````$````%`````,```!'
M3E4`^6,Z-W9\A5S6(KX`A0OHTWA2170E````1`````@````(`````!P0!"5`
M!((X`4`!HH8!J$````)+*`0I.*(R1XH$#`A$````1@``````````````````
M`$@```!*````2P````````!,````30```$\```!0````40```%(`````````
M4P``````````````5````%4```!8``````````````!9````6P```%P```!>
M`````````&````!B``````````````!D````90```&8`````````R-6R<5GH
M[>S.WD<MH^#[2>K3[PZGW:-K+\6;MMO-XYZ'^9R!5J2;EFL)0]8Y\HL<#3J7
M"\6)!9`-%.*>(?_D#@N*$%?$N9Q`:G^:?+,!BV]_J9R;;L7?']EQ6!R[XY)\
MK$OCP-5DU'S@IP(*,V+;[7KP2FMGK\QF0D75[.-'Q@%]08[%P^4_+/+;TQWZ
MH6Q@N8WQ#@````````````````````"Q`@`````````````2````90,`````
M````````$@```.X!`````````````!(```#3`P`````````````2````5@,`
M````````````$@````<!`````````````!(```#,`@`````````````2````
MG0``````````````$@```+@"`````````````!(```!Y```````````````2
M`````@$`````````````$@```&@"`````````````!(````3`P``````````
M```2````>0(`````````````$@```&L!`````````````!(````C`P``````
M```````2````&@,`````````````$@```"L!`````````````!(```"K````
M```````````2````M0$`````````````$@```%(!`````````````!(````W
M`@`````````````2````Y@$`````````````$@```)4"`````````````!(`
M``"B`0`````````````2````A@(`````````````$@```*X!````````````
M`!(````Y`0`````````````2````*@,`````````````$@```!$`````````
M`````"````!)`@`````````````2````-P,`````````````$@```$(`````
M`````````!(```"C`@`````````````2````;`,`````````````$@```-\!
M`````````````!(```#9```````````````2````B```````````````$@``
M`&`!`````````````!(```"J`@`````````````2````@`(`````````````
M$@```%8"`````````````!(````'`@`````````````2````C@(`````````
M````$@```#0``````````````!(````,`0`````````````2````TP(`````
M````````$@```)<!`````````````!(```#F```````````````2````7@,`
M````````````$@```)P"`````````````!(```!Y`0`````````````2````
M(```````````````(````+T``````````````!(```!)`0`````````````2
M````/@,`````````````$@```+X"`````````````!(```!1````````````
M```2````3@(`````````````$@```/0"`````````````!(```#S`0``````
M```````2````X0(`````````````$@```!@"`````````````!(```!?`@``
M```````````2````[`(`````````````$@```/X"`````````````!(```!(
M`P`````````````2````&`$``%"5!`@`````$@```$$$``!(W@0(!````!$`
M#P`!!```0,P$""T,```2``T`2`0``"#)!`B?`0``$@`-`*H#```LW@0(````
M`!(`#@"``P``(%T%"`0````A`!D`L`,``!#&!`@%````$@`-`#$$``"`W00(
M80```!(`#0!H`````)8$"``````2````]P```"A=!0@$````$0`9``X$```@
M`04(`````!``&``,`P``)%T%"`0````1`!D`$`0``"`!!0@`````(``8`'\#
M```@704(!````"$`&0"@`P``\-T$"`(````2``T`700``"#&!`C$`0``$@`-
M`,P````L704(`0```!$`&0!^`P``(%T%"`0````1`!D`>0,``/"6!`CB`0``
M$@`-`'P$``#`R@0(0@```!(`#0#!`P``$,L$""0````2``T`W`,``(#<!`AM
M````$@`-`(\#```$704(`````!``\?^;`P``D&T%"``````0`/'_*`(``$S>
M!`@$````$0`/`*8$``!PV`0("P0``!(`#0`;!```,,4$"-X````2``T`%`0`
M`-28!`@`````$@`-`(<!```@DP0(`````!(```#U`P``(,@$"/(````2``T`
MB`,```1=!0@`````$`#Q_^@#``#PQP0((P```!(`#0"*!```\-P$"$D````2
M``T`500``)#$!`@T````$@`-`,`!```M704($P```!$`&0!J!```0,L$"``!
M```2``T`5P0``%R2!`@`````$@`+``!L:6)P97)L+G-O+C4N,30`7U]G;6]N
M7W-T87)T7U\`7TIV7U)E9VES=&5R0VQA<W-E<P!097)L7W-Y<U]T97)M`%!E
M<FQ?<WES7VEN:70S`%!E<FQ?<V%V95]D97-T<G5C=&]R7W@`4&5R;%]A=&9O
M<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V-R;V%K7VYO8V]N=&5X=`!0
M97)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N
M`%!,7V1O7W5N9'5M<`!097)L7VYE=U-6<'8`4&5R;%]N97=84U]F;&%G<P!0
M3%]T:')?:V5Y`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U
M;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`
M4&5R;%]D;W5N=VEN9`!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`4&5R;%]A
M=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S
M>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO<GE?=W)A<`!L:6)P=&AR96%D
M+G-O+C``;W!E;C8T`&QS965K-C0`<F5A9`!P=&AR96%D7V=E='-P96-I9FEC
M`%]?97)R;F]?;&]C871I;VX`8VQO<V4`;&EB8RYS;RXV`%])3U]S=&1I;E]U
M<V5D`%]?<F5G:7-T97)?871F;W)K`&5X:70`<W1R;F-M<`!?7W-T<F1U<`!C
M;&]S961I<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C
M`&UE;6-H<@!G971P:60`<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R`')M
M9&ER`%]?9G!R:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T
M870V-`!O<&5N9&ER`%]?>'-T870V-`!?7V-T>7!E7V)?;&]C`'-T9&5R<@!G
M971U:60`<F5A9&QI;FL`97AE8W9P`%]?;65M8W!Y7V-H:P!S=')C:'(`<F5A
M9&1I<C8T`%]?<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?
M;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O;@!?961A=&$`7U]B<W-?<W1A<G0`
M7V5N9`!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?97AE8P!G971?=7-E
M<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!P87)?8F%S96YA;64`
M<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`%]?9&%T85]S=&%R=`!P87)?8W5R
M<F5N=%]E>&5C7W!R;V,`7U]L:6)C7V-S=5]I;FET`%]F<%]H=P!P87)?:6YI
M=%]E;G8`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`
M<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T-,14%24U1!0TL`6%-?
M26YT97)N86QS7U!!4E]"3T]4`$=,24)#7S(N,@!'3$E"0U\R+C``1TQ)0D-?
M,BXS`$=,24)#7S(N,RXT`$=,24)#7S(N,RXR`$=,24)#7S(N-`````(``@`#
M``(``@`"``(````"```````$``(``@````(``@````````````4`!@`"````
M`@`"````!P````(``@````(``@`&``````````(``@`"``,``@``````!P``
M`````@`"````````````"``'`````@`(``,`"``#``(``@`)``<````!``$`
M`0`!``(``0`!```````!``(``0`"``$``0````(``0`!``$``0`!``$``0`!
M``$``0````$``0`!``$``0````$``0````$``@#/`0``$````#`````2:6D-
M```&`+P$```0````$&EI#0```P#&!`````````$`!@`>`@``$``````````3
M:6D-```)`-`$```0````$FEI#0``"`"\!```$````'09:0D```<`V@0``!``
M``!R&6D)```%`.8$```0````%&EI#0``!`#R!```$````!!I:0T```(`Q@0`
M``````#P_P0(!AX``"!=!0@%50``)%T%"`5/```H704(!4T``"Q=!0@%5```
M+5T%"`5F``````4(!P$```0`!0@'`@``"``%"`<#```,``4(!P0``!``!0@'
M!0``%``%"`<&```8``4(!P<``!P`!0@'"```(``%"`=@```D``4(!PD``"@`
M!0@'"@``+``%"`<+```P``4(!PP``#0`!0@'#0``.``%"`<.```\``4(!P\`
M`$``!0@'$```1``%"`<1``!(``4(!Q(``$P`!0@'$P``4``%"`<4``!4``4(
M!Q4``%@`!0@'%@``7``%"`<7``!@``4(!Q@``&0`!0@'&0``:``%"`<:``!L
M``4(!QL``'``!0@''```=``%"`<=``!X``4(!QX``'P`!0@''P``@``%"`<@
M``"$``4(!R$``(@`!0@'(@``C``%"`<C``"0``4(!R0``)0`!0@')0``F``%
M"`<F``"<``4(!R<``*``!0@'*```I``%"`<I``"H``4(!RH``*P`!0@'1```
ML``%"`<K``"T``4(!RP``+@`!0@'+0``O``%"`<N``#```4(!R\``,0`!0@'
M,```R``%"`<Q``#,``4(!S(``-``!0@',P``U``%"`<T``#8``4(!TP``-P`
M!0@'-@``X``%"`<W``#D``4(!S@``.@`!0@'.0``[``%"`<Z``#P``4(!SL`
M`/0`!0@'/```^``%"`<]``#\``4(!SX````!!0@'/P``!`$%"`=````(`04(
M!T$```P!!0@'0@``$`$%"`=#``!3@^P(Z`````!;@<./;0``BX/\____A<!T
M!>@%`@``Z.`&``#H>TL``(/$"%O#````````_S7X_P0(_R7\_P0(`````/\E
M```%"&@`````Z>#_____)00`!0AH"````.G0_____R4(``4(:!````#IP/__
M__\E#``%"&@8````Z;#_____)1``!0AH(````.F@_____R44``4(:"@```#I
MD/____\E&``%"&@P````Z8#_____)1P`!0AH.````.EP_____R4@``4(:$``
M``#I8/____\E)``%"&A(````Z5#_____)2@`!0AH4````.E`_____R4L``4(
M:%@```#I,/____\E,``%"&A@````Z2#_____)30`!0AH:````.D0_____R4X
M``4(:'````#I`/____\E/``%"&AX````Z?#^____)4``!0AH@````.G@_O__
M_R5$``4(:(@```#IT/[___\E2``%"&B0````Z<#^____)4P`!0AHF````.FP
M_O___R50``4(:*````#IH/[___\E5``%"&BH````Z9#^____)5@`!0AHL```
M`.F`_O___R5<``4(:+@```#I</[___\E8``%"&C`````Z6#^____)60`!0AH
MR````.E0_O___R5H``4(:-````#I0/[___\E;``%"&C8````Z3#^____)7``
M!0AHX````.D@_O___R5T``4(:.@```#I$/[___\E>``%"&CP````Z0#^____
M)7P`!0AH^````.GP_?___R6```4(:``!``#IX/W___\EA``%"&@(`0``Z=#]
M____)8@`!0AH$`$``.G`_?___R6,``4(:!@!``#IL/W___\ED``%"&@@`0``
MZ:#]____)90`!0AH*`$``.F0_?___R68``4(:#`!``#I@/W___\EG``%"&@X
M`0``Z7#]____):``!0AH0`$``.E@_?___R6D``4(:$@!``#I4/W___\EJ``%
M"&A0`0``Z4#]____):P`!0AH6`$``.DP_?___R6P``4(:&`!``#I(/W___\E
MM``%"&AH`0``Z1#]____);@`!0AH<`$``.D`_?___R6\``4(:'@!``#I\/S_
M__\EP``%"&B``0``Z>#\____)<0`!0AHB`$``.G0_/___R7(``4(:)`!``#I
MP/S___\ES``%"&B8`0``Z;#\____)=``!0AHH`$``.F@_/___R74``4(:*@!
M``#ID/S___\EV``%"&BP`0``Z8#\____)=P`!0AHN`$``.EP_/___R7@``4(
M:,`!``#I8/S___\EY``%"&C(`0``Z5#\____)>@`!0AHT`$``.E`_/___R7L
M``4(:-@!``#I,/S___\E\``%"&C@`0``Z2#\____)?0`!0AHZ`$``.D0_/__
M_R7X``4(:/`!``#I`/S___\E_``%"&CX`0``Z?#[____)0`!!0AH``(``.G@
M^____R4$`04(:`@"``#IT/O___\E"`$%"&@0`@``Z<#[____)0P!!0AH&`(`
M`.FP^____R40`04(:"`"``#IH/O__U6)Y593@^3P@^PPC440B40D"(U%#(E$
M)`2-10B)!"3HG/W__\=$)`A0E00(QT0D!%"5!`C'!"0`E@0(Z!!&``"`/2Q=
M!0@`=2[HHOS__X7`HXQM!0@/A'L!``")!"3H[?O__Z$H704(B00DZ"#____&
M@``#````H2A=!0@QVXD$).@*____@(A#`P```J$H704(B00DZ/;^__^`B$,#
M```!BT4(B5PD+(/`!8E$)"C?;"0HV`6`X00(W06(X00(V<G?Z=W8#X?W````
MP>`"B00DZ&K\__^+=0R+70C'!81M!0@$````BQ:#^P&C@&T%",=`!#7@!`B)
M$,=`"&`!!0C'0`PXX`0(?A6Z`0```&:0BPR6B4R0#(/"`3G:=?*#PP/'!)@`
M````B40D#*&,;04(B5PD",=$)!``````QT0D!-#$!`B)!"3H<_W__X7`B<-T
M-J&,;04(B00DZ$#[__^X^=X$".A6)0``A<!T+*&,;04(B00DZ.7Z___H$/W_
M_XUE^(G86UY=PZ&,;04(B00DZ)K]__^)P^NYH8AM!0B%P'0*B00DZ.5#``#K
MP;BNW@0(Z`DE``"%P*.(;04(=*[KX<=$)`0M704(QP0DJ=X$".@Z_/__QP0D
M`0```.B^^___D)`Q[5Z)X8/D\%!44FCPW00(:(#=!`A15FCPE@0(Z-O[___T
MD)"0D)"0D)"0D%6)Y5.#[`2`/4!=!0@`=3^A1%T%"+L0_P0(@>L,_P0(P?L"
M@^L!.=AS'HVV`````(/``:-$704(_Q2%#/\$"*%$704(.=ARZ,8%0%T%"`&#
MQ`1;7<.-="8`C;PG`````%6)Y8/L&*$4_P0(A<!T$K@`````A<!T"<<$)!3_
M!`C_T,G#D)"0D)"0D)"0D)"0D%6)Q5>#Q3A64S';@>SD`@``B40D5(UV`(MT
MG0"+?)T$QT3<9`````#'1-QL`````(GPP>`(B?J)P8GPP>`8@>$``/\`"<&)
M\`^LT`B)^B4`_P``"<&)\`^LT!B)_B7_````,?\)P8GPP>`(B?J)3-Q@B<&)
M\,'@&('A``#_``G!B?`/K-`()0#_```)P8GP#ZSX&"7_````"<&)3-QH@\,"
M@_L0#X5N____C8PDR````(V<),@"``"+4=B+<9@S$8M!W#-1J(MYG#-!!#-!
MK#'6QT$<`````#''B?`/K/@?B?J)1"0HB?`!\`M$)"C!ZA^)5"0LB4$8@\$(
M.=EUN8M,)%2+="14BVPD5(L1BUX(BTD$BWT0B50D((M4)%2)7"08BUPD5(MV
M#(E,)"2+;12+0AB+2R")="0<BW0D((E\)!"+?"0DB40D"(M2'(G(BULD`T0D
M8(D,)(EL)!2+;"00!9EY@EH/K/X;BWPD((GQBW0D%(E4)`R)7"0$P><%"?D!
MR(M,)!@C="0<(VPD&/?1(TPD"(ET)"B+5"0<BUPD((G.BTPD&`GN`?`Q_XG&
MBT0D&,'A'L=$)$0`````QT0D/``````/K-`"BU0D)(G%BT0D"`G-BTPD(`-$
M)&B);"1`!9EY@EKWT2'KBVPD)"-,)!`)RXGQB5PD*/?5(VPD%`-$)"@/K/D;
MB4PD*(GQP>$%B4PD,(M,)"@+3"0PB6PD+,=$)"P``````<B+3"0@B40D*(M$
M)"#!X1X/K-`"B<6+1"00"<V)\0-$)'#WT8GKB6PD.`69>8):(?,C3"1`"=F)
M3"0PQT0D-`````"+7"0LBTPD*`-$)##'1"0T`````(M4)"S'1"1,``````^L
MV1N)3"0PBTPD*,=$)$0`````P>$%B4PD2(M,)#`+3"1(`<B+3"0HB40D,(GP
M#ZSX`HM\)#3!YAZ)PXM$)$`)\_?1`T0D>(E<)$B+7"0H!9EY@EHAZ2-<)$B)
MS@G>BUPD,`'PBW0D,`^L_AN+?"0PB?'!YP4)^0'(BTPD*#'_B<:+1"0HP>$>
M#ZS0`HG%BT0D.`G-BTPD,`.$)(````");"1`!9EY@EKWT2-,)$@AZPG9B4PD
M*(GQBU0D-`-$)"@/K/D;B4PD*(GQP>$%B4PD.(M,)"@+3"0XQT0D+`````#'
M1"0L``````'(BTPD,(E$)"B+1"0PQT0D-`````#'1"0T`````,'A'@^LT`*+
M5"0LB<6+1"1("<V)\0.$)(@```#WT8GKB6PD.`69>8):(?,C3"1`QT0D/```
M``#'1"1,``````G9BUPD+(E,)#"+3"0H`T0D,`^LV1N)3"0PBTPD*,'A!8E,
M)$B+3"0P"TPD2`'(BTPD*(E$)#")\`^L^`*+?"0TP>8>B<.+1"1`"?/WT0.$
M))````")7"1(BUPD*`69>8):(>DC7"1(B<X)W@'PBW0D,`^L_AN+?"0PB?'!
MYP4)^0'(BTPD*#'_B<:+1"0HP>$>#ZS0`HG%"<V);"1`BT0D.(M,)#`#A"28
M````BUPD,(M4)#0%F7F"6O?1(TPD2"'KQT0D+``````)V8E,)"B)\0-$)"@/
MK/D;B4PD*(GQP>$%B4PD.(M,)"@+3"0XQT0D+`````#'1"1$``````'(BTPD
M,(E$)"B+1"0PQT0D/`````#'1"0T`````,'A'@^LT`*)Q8M$)$@)S8GQ`X0D
MH````/?1B>N);"0X!9EY@EHA\R-,)$`)V8M<)"R)3"0PBTPD*`-$)#`/K-D;
MB4PD,(M,)"C!X06)3"1(BTPD,`M,)$C'1"0T`````(M4)"S'1"1,``````'(
MBTPD*(E$)#")\`^L^`*+?"0TP>8>B<.+1"1`"?/WT0.$)*@```")7"1(BUPD
M*,=$)$0`````!9EY@EHAZ2-<)$B)SL=$)"P`````"=Z+7"0P`?"+="0P#ZS^
M&XM\)#")\<'G!0GY`<B+3"0H,?^)QHM$)"C!X1X/K-`"B<6+1"0X"<V+3"0P
M`X0DL````(EL)$`%F7F"6O?1(TPD2"'K"=F)3"0HB?$#1"0H#ZSY&XE,)"B)
M\<'A!8E,)#B+3"0H"TPD.`'(B40D*(M$)#"+5"0TBTPD,,=$)"P`````QT0D
M-``````/K-`"BU0D+,'A'HG%BT0D2`G-B?$#A"2X````]]&)Z\=$)#0`````
M!9EY@EHA\R-,)$");"0XQT0D/``````)V8M<)"R)3"0PBTPD*`-$)##'1"1,
M``````^LV1N)3"0PBTPD*,'A!8E,)$B+3"0P"TPD2`'(BTPD*(E$)#")\`^L
M^`*+?"0TP>8>B<.+1"1`"?/WT0.$),````")7"1(BUPD*`69>8):(>DC7"1(
MB<X)W@'PBW0D,`^L_AN+?"0PB?'!YP4)^0'(BTPD*#'_B<:+1"0HP>$>#ZS0
M`HG%"<V);"1`BT0D.(M,)#`#A"3(````BUPD,(M4)#0%F7F"6O?1(TPD2"'K
MQT0D+``````)V8E,)"B)\0-$)"@/K/D;B4PD*(GQP>$%B4PD.(M,)"@+3"0X
MQT0D+`````#'1"1$``````'(BTPD,(E$)"B+1"0PQT0D/`````#'1"0T````
M`,'A'@^LT`*)Q8M$)$@)S8GQ`X0DT````/?1B>N);"0X!9EY@EHA\R-,)$`)
MV8M<)"R)3"0PBTPD*`-$)#`/K-D;B4PD,(M,)"C!X06)3"1(BTPD,`M,)$C'
M1"0T`````(M4)"S'1"1,``````'(BTPD*(E$)#")\`^L^`*+?"0TP>8>B<.+
M1"1`"?/WT0.$)-@```")7"1(BUPD*,=$)$0`````!9EY@EHAZ2-<)$B)SL=$
M)"P`````"=Z+7"0P`?"+="0P#ZS^&XM\)#")\<'G!0GY`<B+3"0H,?^)QHM$
M)"C!X1X/K-`"B<6+1"0X"<V+3"0P`X0DX````(EL)$`%F7F"6O?1(TPD2"'K
M"=F)3"0HB?$#1"0H#ZSY&XE,)"B)\<'A!8E,)#B+3"0H"TPD.`'(B40D*(M$
M)#"+5"0TBTPD,,=$)"P`````QT0D-``````/K-`"BU0D+,'A'HG%BT0D2`G-
MB?$#A"3H````]]&)Z\=$)#0`````!9EY@EHA\R-,)$");"0XQT0D/``````)
MV8M<)"R)3"0PBTPD*`-$)##'1"1,``````^LV1N)3"0PBTPD*,'A!8E,)$B+
M3"0P"TPD2`'(BTPD*(E$)#")\`^L^`*+?"0TP>8>B<.+1"1`"?/WT0.$)/``
M``")7"1(BUPD*`69>8):(>DC7"1(B<X)W@'PBW0D,`^L_AN+?"0PB?'!YP4)
M^0'(BTPD*#'_B<:+1"0HP>$>#ZS0`HG%"<V);"1`BT0D.(M,)#`#A"3X````
MBUPD,(M4)#0%F7F"6O?1(TPD2"'KQT0D+``````)V8E,)"B)\0-$)"@/K/D;
MB4PD*(GQP>$%B4PD.(M,)"@+3"0XQT0D+`````"+7"0LQT0D1``````!R(M,
M)#")1"0HBT0D,,=$)#P`````P>$>#ZS0`HG%BT0D2`G-`X0D``$``(EL)#@%
MH>O9;C-L)$")Z3'Q`<B+3"0H#ZS9&XE,)#"+3"0HP>$%B4PD2(M,)#`+3"1(
M`<B)1"0PB?"+3"0H#ZSX`HM4)"S!YAZ)PXM$)$`)\XMT)#@#A"0(`0``QT0D
M-`````"+?"0TB5PD2`6AZ]EN,=XQ\8MT)#`!R,=$)"P`````BUPD+,=$)$P`
M````#ZS^&XM\)#")\<=$)$0`````QT0D/`````#!YP4)^0'(BTPD*#'_B<:+
M1"0HP>$>#ZS0`HM4)#2)Q8M$)#@)S8M,)#`#A"00`0``B6PD0`6AZ]EN,VPD
M2#'I`<B)\0^L^1N)3"0HB?'!X06)3"0XBTPD*`M,)#@!R(M,)#")1"0HBT0D
M,,'A'@^LT`*)Q8M$)$@)S0.$)!@!``");"0X!:'KV6XS;"1`B>DQ\0'(BTPD
M*`^LV1N)3"0PBTPD*,=$)#0`````BU0D+,=$)$P`````QT0D1`````#!X06)
M3"1(BTPD,`M,)$C'1"0L``````'(BTPD*(E$)#")\`^L^`*+?"0TP>8>B<.+
M1"1`"?.+="0X`X0D(`$``(E<)$@%H>O9;C'>,?&+="0P`<@/K/X;BWPD,(GQ
MP><%"?D!R(M,)"@Q_XG&BT0D*,'A'@^LT`*+5"0TB<6+1"0X"<V+3"0P`X0D
M*`$``(EL)$`%H>O9;C-L)$@QZ0'(B?$/K/D;B4PD*(GQP>$%B4PD.(M,)"@+
M3"0X`<B+3"0PB40D*(M$)##!X1X/K-`"B<4)S8EL)#B+1"1(`X0D,`$``(M<
M)"S'1"0T`````(M4)"P%H>O9;C-L)$#'1"0\`````,=$)$P`````B>DQ\0'(
MBTPD*,=$)$0`````#ZS9&XE,)#"+3"0HP>$%B4PD2(M,)#`+3"1(`<B+3"0H
MB40D,(GP#ZSX`HM\)#3!YAZ)PXM$)$`)\XMT)#@#A"0X`0``B5PD2`6AZ]EN
M,=XQ\8MT)#`!R`^L_AN+?"0PB?'!YP4)^0'(BTPD*#'_B<:+1"0HP>$>#ZS0
M`HG%BT0D.`G-BTPD,`.$)$`!``");"1`!:'KV6XS;"1(,>D!R(GQ#ZSY&XE,
M)"B)\8M4)#3!X06)3"0XBTPD*`M,)#C'1"0L`````(M<)"S'1"0T``````'(
MBTPD,(E$)"B+1"0PQT0D/`````#'1"1,`````,'A'@^LT`*+5"0LB<6+1"1(
M"<T#A"1(`0``B6PD.`6AZ]EN,VPD0(GI,?$!R(M,)"@/K-D;B4PD,(M,)"C!
MX06)3"1(BTPD,`M,)$@!R(M,)"B)1"0PB?`/K/@"BWPD-,'F'HG#BT0D0`GS
MBW0D.`.$)%`!``")7"1(!:'KV6XQWC'QBW0D,`'(#ZS^&XM\)#")\<'G!0GY
M`<B+3"0H,?^)QHM$)"C!X1X/K-`"B<4)S8EL)$"+1"0X`X0D6`$``(M,)#"+
M5"0T!:'KV6XS;"1(QT0D+`````"+7"0LQT0D-``````QZ0'(B?$/K/D;B4PD
M*(GQP>$%B4PD.(M,)"@+3"0XQT0D1`````#'1"0\``````'(BTPD,(E$)"B+
M1"0PQT0D3`````#!X1X/K-`"BU0D+(G%BT0D2`G-`X0D8`$``(EL)#@%H>O9
M;C-L)$")Z3'Q`<B+3"0H#ZS9&XE,)#"+3"0HP>$%B4PD2(M,)#`+3"1(`<B+
M3"0HB40D,(GP#ZSX`HM\)#3!YAZ)PXM$)$`)\XMT)#@#A"1H`0``B5PD2`6A
MZ]EN,=XQ\8MT)#`!R`^L_AN+?"0PB?'!YP4)^0'(BTPD*#'_B<:+1"0HP>$>
M#ZS0`HG%"<V);"1`BT0D.`.$)'`!``"+3"0PBU0D-`6AZ]EN,VPD2,=$)"P`
M````BUPD+,=$)#0`````,>D!R(GQ#ZSY&XE,)"B)\<'A!8E,)#B+3"0H"TPD
M.,=$)$0`````QT0D/``````!R(M,)#")1"0HBT0D,,=$)$P`````P>$>#ZS0
M`HM4)"R)Q8M$)$@)S0.$)'@!``");"0X!:'KV6XS;"1`B>DQ\0'(BTPD*`^L
MV1N)3"0PBTPD*,'A!8E,)$B+3"0P"TPD2`'(BTPD*(E$)#")\`^L^`*+?"0T
MP>8>B<.+1"1`"?.+="0X`X0D@`$``(E<)$@%H>O9;C'>,?&+="0P`<@/K/X;
MBWPD,(GQP><%"?D!R(M,)"@Q_XG&BT0D*,'A'@^LT`*)Q0G-B6PD0(M$)#@#
MA"2(`0``BTPD,(M4)#0%H>O9;C-L)$C'1"0L`````(M<)"S'1"0T`````#'I
M`<B)\0^L^1N)3"0HB?'!X06)3"0XBTPD*`M,)#C'1"1$`````,=$)%P`````
M`<B+3"0PB40D*(M$)##'1"0\`````,'A'@^LT`*+5"0LB<6+1"1("<T#A"20
M`0``B6PD6`6AZ]EN,VPD0(GI,?$!R(M,)"@/K-D;B4PD,(M,)"C!X06)3"0X
MBTPD,`M,)#@!R(M,)"B)1"0PB?`/K/@"BWPD-,'F'HG#BT0D0`GSBW0D6`.$
M))@!``")7"0X!:'KV6XQWC'QBW0D,`'(#ZS^&XM\)#")\<'G!0GY`<B+3"0H
M,?^)QHM$)"C!X1X/K-`"B<4)S8EL)"B+3"0XBT0D6`.$)*`!``"+7"0XBU0D
M-`7<O!N/">DC3"0P(>O'1"1$``````G9BUPD*(E,)$")\0-$)$`/K/D;B4PD
M0(GQP>$%B4PD2(M,)$`+3"1(QT0D1`````#'1"0L``````'(BTPD,(E$)$"+
M1"0PQT0D-`````#'1"0\`````,'A'@^LT`*)Q8M$)#@)S8M,)"@#A"2H`0``
MB6PD,`7<O!N/">DAZR'Q"=F+7"1$B4PD.(M,)$`#1"0X#ZS9&XE,)#B+3"1`
MQT0D/`````"+5"1$QT0D3`````#'1"0L`````,'A!8E,)$B+3"0X"TPD2,=$
M)#0``````<B)1"0XB?`/K/@"BWPD/,'F'HG#BT0D*`GS`X0DL`$``(G9B5PD
M2`7<O!N/">DC3"1`(>N)S@G>BUPD2`'PBW0D.`^L_AN+?"0XB?'!YP4)^0'(
MBTPD0#'_B<:+1"1`P>$>#ZS0`HG%BT0D,`G-BTPD2`.$)+@!``");"0H!=R\
M&X\)Z2-,)#@AZPG9B4PD,(GQ`T0D,`^L^1N)3"0PB?'!X06)3"1`BTPD,`M,
M)$`!R(E$)#"+1"0XBU0D/(M,)#B+7"0HQT0D-``````/K-`"BU0D-,'A'HG%
MBT0D2`G-BTPD*`.$),`!``#'1"0\`````,=$)#P`````!=R\&X\)Z2'K(?$)
MV8M<)#2)3"0XBTPD,`-$)#B);"1`QT0D1``````/K-D;B4PD.(M,)##'1"1,
M`````,'A!8E,)$B+3"0X"TPD2`'(B40D.(GP#ZSX`HM\)#S!YAZ)PXM$)"@)
M\P.$),@!``")V8E<)$@%W+P;CPGI(TPD,"'KB<X)W@'PBW0D.`^L_AN+?"0X
MB?'!YP4)^0'(BTPD,#'_B<:+1"0PP>$>#ZS0`HG%"<V);"0HBT0D0(M,)$@#
MA"30`0``BUPD2(M4)#P%W+P;CPGI(TPD."'KQT0D-``````)V8M<)"B)3"0P
MB?$#1"0P#ZSY&XE,)#")\<'A!8E,)$"+3"0P"TPD0,=$)#0`````QT0D+```
M```!R(M,)#B)1"0PBT0D.,=$)$0`````QT0D/`````#!X1X/K-`"B<6+1"1(
M"<V+3"0H`X0DV`$``(EL)$`%W+P;CPGI(>LA\0G9BUPD-(E,)#B+3"0P`T0D
M.`^LV1N)3"0XBTPD,,=$)#P`````BU0D-,=$)$P`````QT0D+`````#!X06)
M3"1(BTPD.`M,)$C'1"0T``````'(B40D.(GP#ZSX`HM\)#S!YAZ)PXM$)"@)
M\P.$).`!``")V8E<)$@%W+P;CPGI(TPD,"'KB<X)WHM<)$@!\(MT)#@/K/X;
MBWPD.(GQP><%"?D!R(M,)#`Q_XG&BT0D,,'A'@^LT`*)Q8M$)$`)S8M,)$@#
MA"3H`0``B6PD*`7<O!N/">DC3"0X(>L)V8E,)#")\0-$)#`/K/D;B4PD,(GQ
MP>$%B4PD0(M,)#`+3"1``<B)1"0PBT0D.(M4)#R+3"0XBUPD*,=$)#0`````
M#ZS0`HM4)#3!X1Z)Q8M$)$@)S8M,)"@#A"3P`0``QT0D/`````#'1"0\````
M``7<O!N/">DAZR'Q"=F+7"0TB4PD.(M,)#`#1"0XB6PD0,=$)$0`````#ZS9
M&XE,)#B+3"0PQT0D3`````#!X06)3"1(BTPD.`M,)$@!R(E$)#B)\`^L^`*+
M?"0\P>8>B<.+1"0H"?,#A"3X`0``B=F)7"1(!=R\&X\)Z2-,)#`AZXG."=X!
M\(MT)#@/K/X;BWPD.(GQP><%"?D!R(M,)#`Q_XG&BT0D,,'A'@^LT`*)Q0G-
MB6PD*(M$)$"+3"1(`X0D``(``(M<)$B+5"0\!=R\&X\)Z2-,)#@AZ\=$)#0`
M````"=F+7"0HB4PD,(GQ`T0D,`^L^1N)3"0PB?'!X06)3"1`BTPD,`M,)$#'
M1"0T`````,=$)"P``````<B+3"0XB40D,(M$)#C'1"1$`````,=$)#P`````
MP>$>#ZS0`HG%BT0D2`G-BTPD*`.$)`@"``");"1`!=R\&X\)Z2'K(?$)V8M<
M)#2)3"0XBTPD,`-$)#@/K-D;B4PD.(M,)##'1"0\`````(M4)#3'1"1,````
M`,=$)"P`````P>$%B4PD2(M,)#@+3"1(QT0D-``````!R(E$)#B)\`^L^`*+
M?"0\P>8>B<.+1"0H"?,#A"00`@``B=F)7"1(!=R\&X\)Z2-,)#`AZXG."=Z+
M7"1(`?"+="0X#ZS^&XM\)#B)\<'G!0GY`<B+3"0P,?^)QHM$)##!X1X/K-`"
MB<6+1"1`"<V+3"1(`X0D&`(``(EL)"@%W+P;CPGI(TPD."'K"=F)3"0PB?$#
M1"0P#ZSY&XE,)#")\<'A!8E,)$"+3"0P"TPD0`'(B40D,(M$)#B+5"0\BTPD
M.(M<)"C'1"0T``````^LT`*+5"0TP>$>B<6+1"1("<V+3"0H`X0D(`(``,=$
M)#P`````QT0D/``````%W+P;CPGI(>LA\0G9BUPD-(E,)#B+3"0P`T0D.(EL
M)$#'1"1$``````^LV1N)3"0XBTPD,,=$)$P`````P>$%B4PD2(M,)#@+3"1(
M`<B)1"0XB?`/K/@"BWPD/,'F'HG#BT0D*`GS`X0D*`(``(G9B5PD2`7<O!N/
M">DC3"0P(>N)S@G>`?"+="0X#ZS^&XM\)#B)\<'G!0GY`<B+3"0P,?^)QHM$
M)##!X1X/K-`"B<4)S8EL)"B+1"1`BTPD2`.$)#`"``"+7"1(BU0D/`7<O!N/
M">DC3"0X(>O'1"0T``````G9BUPD*(E,)#")\0-$)#`/K/D;B4PD,(GQP>$%
MB4PD0(M,)#`+3"1`QT0D-`````#'1"0L``````'(BTPD.(E$)#"+1"0XQT0D
M/`````#'1"1$`````,'A'@^LT`*)Q8M$)$@)S8M,)"@#A"0X`@``B6PD.`7<
MO!N/">DAZR'Q"=F+7"0TB4PD0(M,)#`#1"1`#ZS9&XE,)$"+3"0PQT0D1```
M``"+5"0TQT0D3`````#'1"1<`````,'A!8E,)$B+3"1`"TPD2,=$)"P`````
M`<B+3"0PB40D0(GP#ZSX`HM\)$3!YAZ)PXM$)"@)\P.$)$`"``")WHE<)$@%
MUL%BRC'N,?&+="1``<@/K/X;BWPD0(GQP><%"?D!R(M,)#`Q_XG&BT0D,,'A
M'@^LT`*+5"1$B<6+1"0X"<V+3"1``X0D2`(``(EL)%@%UL%BRC-L)$@QZ0'(
MB?$/K/D;B4PD*(GQP>$%B4PD,(M,)"@+3"0P`<B+3"1`B40D*(M$)$#!X1X/
MK-`"B<4)S8EL)$"+1"1(`X0D4`(``(M<)"S'1"0T`````(M4)"P%UL%BRC-L
M)%C'1"1$`````,=$)#P`````B>DQ\0'(BTPD*,=$)$P`````#ZS9&XE,)#"+
M3"0HP>$%B4PD.(M,)#`+3"0X`<B+3"0HB40D,(GP#ZSX`HM\)#3!YAZ)PXM$
M)%@)\XMT)$`#A"18`@``B5PD.`76P6+*,=XQ\8MT)#`!R`^L_AN+?"0PB?'!
MYP4)^0'(BTPD*#'_B<:+1"0HP>$>#ZS0`HG%BT0D0`G-BTPD,`.$)&`"``")
M;"1(!=;!8LHS;"0X,>D!R(GQ#ZSY&XE,)"B)\8M4)#3!X06)3"1`BTPD*`M,
M)$#'1"0L`````(M<)"S'1"0T``````'(BTPD,(E$)"B+1"0PQT0D1`````#'
M1"0\`````,'A'@^LT`*+5"0LB<6+1"0X"<T#A"1H`@``B6PD0`76P6+*,VPD
M2(GI,?$!R(M,)"@/K-D;B4PD,(M,)"C!X06)3"0XBTPD,`M,)#@!R(M,)"B)
M1"0PB?`/K/@"BWPD-,'F'HG#BT0D2`GSBW0D0`.$)'`"``")7"0X!=;!8LHQ
MWC'QBW0D,`'(#ZS^&XM\)#")\<'G!0GY`<B+3"0H,?^)QHM$)"C!X1X/K-`"
MB<4)S8EL)$B+1"1``X0D>`(``(M,)#"+5"0T!=;!8LHS;"0XQT0D+`````"+
M7"0LQT0D-``````QZ0'(B?$/K/D;B4PD*(GQP>$%B4PD0(M,)"@+3"1`QT0D
M3`````#'1"1$``````'(BTPD,(E$)"B+1"0PQT0D/`````#!X1X/K-`"BU0D
M+(G%BT0D.`G-`X0D@`(``(EL)$`%UL%BRC-L)$B)Z3'Q`<B+3"0H#ZS9&XE,
M)#"+3"0HP>$%B4PD.(M,)#`+3"0X`<B+3"0HB40D,(GP#ZSX`HM\)#3!YAZ)
MPXM$)$@)\XMT)$`#A"2(`@``B5PD.`76P6+*,=XQ\8MT)#`!R`^L_AN+?"0P
MB?'!YP4)^0'(BTPD*#'_B<:+1"0HP>$>#ZS0`HG%"<V);"1(BT0D0`.$))`"
M``"+3"0PBU0D-`76P6+*,VPD.,=$)"P`````BUPD+,=$)#0`````,>D!R(GQ
M#ZSY&XE,)"B)\<'A!8E,)$"+3"0H"TPD0,=$)$P`````QT0D1``````!R(M,
M)#")1"0HBT0D,,=$)#P`````P>$>#ZS0`HM4)"R)Q8M$)#@)S0.$))@"``")
M;"1`!=;!8LHS;"1(B>DQ\0'(BTPD*`^LV1N)3"0PBTPD*,'A!8E,)#B+3"0P
M"TPD.`'(BTPD*(E$)#")\`^L^`*+?"0TP>8>B<.+1"1("?.+="1``X0DH`(`
M`(E<)#@%UL%BRC'>,?&+="0P`<@/K/X;BWPD,(GQP><%"?D!R(M,)"@Q_XG&
MBT0D*,'A'@^LT`*)Q0G-B6PD2(M$)$`#A"2H`@``BTPD,(M4)#0%UL%BRC-L
M)#C'1"0L`````(M<)"S'1"0T`````#'I`<B)\0^L^1N)3"0HB?'!X06)3"1`
MBTPD*`M,)$#'1"1,`````,=$)$0``````<B+3"0PB40D*(M$)##'1"0\````
M`,'A'@^LT`*+5"0LB<6+1"0X"<T#A"2P`@``B6PD0`76P6+*,VPD2(GI,?$!
MR(M,)"@/K-D;B4PD,(M,)"C!X06)3"0XBTPD,`M,)#@!R(M,)"B)1"0PB?`/
MK/@"BWPD-,'F'HG#BT0D2`GSBW0D0`.$)+@"``")7"0X!=;!8LHQWC'QBW0D
M,`'(#ZS^&XM\)#")\<'G!0GY`<B+3"0H,?^)QHM$)"C!X1X/K-`"B<4)S8EL
M)$B+1"1``X0DP`(``(M,)#"+5"0T!=;!8LHS;"0XQT0D+`````"+7"0LQT0D
M3``````QZ0'(B?$/K/D;B4PD*(GQP>$%B4PD0(M,)"@+3"1`QT0D-`````#'
M1"1$``````'(BTPD,(E$)"B+1"0PP>$>#ZS0`HG%BT0D.`G-`X0DR`(``(EL
M)#`%UL%BRC-L)$B)Z3'Q`<B+3"0H#ZS9&XE,)$"+3"0HP>$%B4PD.(M,)$`+
M3"0X`<@QVXG!B?`/K/@"B<_!YAZ)Q8M$)$@)]8MT)"@#A"30`@``B6PD0`76
MP6+*,VPD,#'N`?")S@^LWAN)="0XP><%BW0D.(E\)$B+5"0L"W0D2,=$)"P`
M````QT0D/``````!\#'_B<:+1"0H#ZS0`HG:B40D2(M$)"C!Z@*)5"1,B=H/
MI,H>B50D7,'@'@M$)$B)1"0XB<@/K-@"BUPD.(E$)$B)R,'@'HE$)%B+1"0P
M`X0DV`(```76P6+*,UPD0#'+B?&)7"0HB?L#1"0H#ZSY&XE,)"B)\<'A!8E,
M)#"+3"0HP>L;"TPD,(E<)"R)^P^D\P4!R(G!BT0D5`-,)"")7"0TB0C'0`0`
M````BT0D&(M,)%0!\(E!"(M$)$@+1"18`T0D$,=!#`````#'010`````B4$0
MBT0D.`-$)`C'01P`````QT$D`````(E!&(M$)$`#!"2)02"!Q.0"``!;7E]=
MPU575E.)PX/L+(7`B50D''1*H2!=!0B%P(E$)!AT/0^V`SP]=4,Q[8M$)!B+
M,#'`A?9T*HM\)!B0B6PD"(E<)`2)-"3H&-G__X7`=0:`/"X]=#:#QP2+-X7V
M==TQP(/$+%M>7UW#C78`A,!TN8G=@\4!#[9%`#P]=`2$P'7Q*=WKIHVT)@``
M``"+1"0<*WPD&,'_`HDX@\0LC40N`5M>7UW#ZPV0D)"0D)"0D)"0D)"0@^P<
MC50D#.A$____@\0<PU.)PX/L&(U4)`R)V.@O____A<!T-HUV`(L5(%T%"(M$
M)`R-!(*+4`2%THD0=-AFD(/`!(M0!(72B1!U](U4)`R)V.CY_O__A<!US8/$
M&%O#5E.#[!2A*%T%"(D$).A>V/__BX!P`0``BW`$H2A=!0B)!"3H2-C__P^V
MF/@"``"A*%T%"(/C?XD$).@QV/__BT`$#[=`$,'@!PG89HE&`J$H704(B00D
MZ!38__^+@'`!``"+6`2A*%T%"(D$).C^U___QT0D"`````#'1"0$+^`$"(D$
M).A6UO__B4,<H2A=!0B)!"3HUM?__XN`<`$``(M8!*$H704(B00DZ,#7__^+
M@/@#``")0R"A*%T%"(D$).BJU___BX!P`0``BU@$H2A=!0B)!"3HE-?__S'2
MBX@8!@``A<ET%J$H704(B00DZ'O7__^+@!@&``"+4'"A*%T%"(E3)(D$).AB
MU___BX!P`0``BT`$QT`H`````*$H704(B00DZ$77__^+@'`!``"+0`3'0!@`
M````H2A=!0B)!"3H*-?__XN`<`$``(M8!*$H704(B00DZ!+7__^+@'@!``")
M0RR#Q!1;7L.-=@"![)P```"%P(F\))0```")QXF<)(P```")M"20````B:PD
MF````'0%@#@`=2.+G"2,````B[0DD````(N\))0```"+K"28````@<2<````
MPXD$).CHUO__A<")QG3/9I")-"3H2-;__X7`B<,/A*8```"`>Q,N#X2T````
MB3PD@\,3Z+G4__^)'"2)Q>BOU/__C40%`HD$).@SU/__B5PD%(E\)!#'1"0,
M4-X$",=$)`C_____QT0D!`$```")Q8D$).B9UO__C40D((E$)`B);"0$QP0D
M`P```.@1UO__@_C_=!"+1"0P)0#P```]`$```'1DB2PDZ`33__^)+"3H;-+_
M_XDT).BDU?__A<")PP^%7/___V:0B30DZ!#6__^)/"3HB-+__^D`____C78`
M@'L4``^$)O___X![%"YFD`^%-O___X![%0`/A!#____I)____XUV`(GHZ*'^
M__^0ZYJ-M"8`````C;PG`````%:)QE,QVX/L%*$H704(B00DZ'K5__^)="0$
MQP0D`P```(/`7(E$)`CH<]7__X7`=`^#Q!2)V%M>PXVT)@````"A*%T%"(D$
M).A#U?__BT!L)0#P```]`$```'0<H2A=!0B)!"3H)]7__XM`;"4`\```/0"@
M``!UN8DT)#';QT0D!`(```#H5M3__X7`#Y3#@\04B=A;7L.)]HV\)P````!5
M5U:)QE,QP(/L/(G3@#H]#Y3``<.)'"3H$]/__XU4)"R)1"0<B?#H1/O__X7`
MB<</A.H```")!"3H\M+__S'2.40D'`^&M@```(M,)"S!X0(/M@8\/0^$=`$`
M`(3`#X1L`0``B?#K!(32=`N#P`$/MA"`^CUU\2GPBU0D'(L](%T%"(U$$`(!
MSXD$).@OTO__A<")!P^$/`$``(M4)"RA(%T%"(L$D`^V%H32B!!T)(#Z/70?
M@\8!ZPN-M@````"`^CUT#P^V%H/``8/&`832B!!U[,8`/3'2C;0F``````^V
M#!.(3!`!@\(!A,EU\3'`@\0\6UY?7<.-M"8`````#[8$$X@$%X/"`83`=.$/
MM@03B`07@\(!A,!UY.O19I"++2!=!0@Q_[@(````BU4`A=)T%HUT)@"#QP&+
M3+T`A<EU]8T$O0@```"+%6!=!0B%TG0TB40D!(DL).A0T?__A<")PJ,@704(
M=&R-#+T`````QT2Z!`````")?"0LZ<[^__^0C70F`,<%8%T%"`$```")!"3H
M)M'__X7`=#F-#+T`````B4PD"(E,)!2);"0$B00DB40D&.B3S___BU0D&(M,
M)!2)%2!=!0CKI8UV`#'`Z:+^__^X_____^D0____ZPV0D)"0D)"0D)"0D)"0
M@>P\$```B;PD-!```(U\)!R)G"0L$```B<.)K"0X$```B=5EH10```")A"0<
M$```,<")M"0P$```QT0D"/\/``")?"0$QP0D5MX$".C?S___A<`/CH<```"-
M</^`?#0<`'1UB<:)="0(QT0D!"\```")/"3H=]'__X7`=&.A*%T%"(D$).AV
MTO__B70D#(E\)`B)7"0$B00DZ/+1__^+A"0<$```93,%%````'51BYPD+!``
M`(NT)#`0``"+O"0T$```BZPD.!```('$/!```,.-M"8`````A?9UB8UT)@"A
M*%T%"(D$).@3TO__B6PD"(E<)`2)!"3H0\___^N?Z-S.__^-M@````"-OP``
M``"#[!RA*%T%"(D$).C@T?__QT0D#&7>!`C'1"0((),$",=$)`1OW@0(B00D
MZ%#0__^#Q!S#C;8`````C;\`````@^PLH2A=!0B)!"3HH-'__XD$).BH____
MH2A=!0B)!"3HB]'__\=$)!0`````QT0D$"_@!`C'1"0,+^`$",=$)`APV`0(
MQT0D!(O>!`B)!"3HF]#__X/$+,.-M"8`````@>P\(```B9PD,"```#';B;0D
M-"```(UT)"IEH10```")A"0L(```,<")O"0X(```Z+O.___'1"048=X$",=$
M)`R@W@0(QT0D"`$0``#'1"0$`0```(DT)(E$)!#H3]'__X7`>$:-O"0K$```
MB30DQT0D"``0``")?"0$Z`#.__^%P(G&>"6-0`&)!"3HC\[__X7`B<-T%(ET
M)`B)?"0$B00DZ"G-___&!#,`BY0D+"```&4S%10```")V'4<BYPD,"```(NT
M)#0@``"+O"0X(```@<0\(```P^A2S?__9I#I&____XUT)@"-O"<`````55=6
M4X'L3!```&6A%````(F$)#P0```QP+BNW@0(BYPD8!```(NT)&00``#H7_?_
M_\=$)`0O````B1PDB<7H/<[__X7`="V)VKBWW@0(Z!W[__^+E"0\$```93,5
M%````(G8#X56`0``@<1,$```6UY?7<.)'"3H),[__\=$)`3$W@0(B30DB40D
M+.@PS___A<")QW2QC70D/(VV`````(`_`+JLW@0(#T3ZA>UT%(E\)`2)+"3H
MU<O__X7`#X2J````B3PDZ-7-__^`?`?_+W44C;8`````@^@!@'P'_R_&!`<`
M=/*+5"0LC400`3W_#P``#X].____B5PD&,=$)!3&W@0(B7PD$,=$)`SEWP0(
MQT0D"``0``#'1"0$`0```(DT).B7S___H2A=!0B)!"3H*L___XET)`3'!"0#
M````@\!<B40D".@#S___A<!U'*$H704(B00DZ`+/__^+0&PE`/```#T`@```
M="/'1"0$Q-X$",<$)`````#H/\[__X7`B<</A17____IM_[__\=$)`0!````
MB30DZ!#.__^%P'7)B?*XM]X$".C`^?__B30DZ&C-__^)P^F4_O__Z'S+__^-
MM@````"-OP````"+1"0$#[8(A,ET%HU0`6:0@/DO#T3"@\(!#[9*_X3)=>_S
MPXVV`````(V\)P````!3@^P8BUPD((7;=#2`.P!T+XD<).B'S/__C40#_SG#
M<A+K29"-="8`@^@!.=@/A(4```"`."]T\.LKC;8`````QP0D`@```.CDR___
MA<!T!6;'`"X`@\086\.-M@````"`."]T!X/H`3G#<O0YV'1(@^@!.<-S!8`X
M+W3TB<(QP"G:C4H"@?D`$```=\B#P@&)7"0$QT0D#``0``")5"0(QP0D@%T%
M".C4S/__@\08N(!=!0A;PV:0@#@O=!''1"0@QMX$"(/$&%OI4LS__\<$)`(`
M``#H5LO__XG",<"%T@^$;____V;'`BX`B=#I8____XVT)@````"-O"<`````
M5U:#[#1EH10```")1"0L,<"A/.`$"(E$)`JA0.`$"(E$)`ZA1.`$"(E$)!*A
M2.`$"(E$)!:A3.`$"(E$)!JA4.`$"(E$)!ZA5.`$"(E$)"*A6.`$"(E$)"8/
MMP5<X`0(9HE$)"JXR-X$".@Q]/__N-'>!`CH)_3__[C9W@0(Z!WT__^XXMX$
M".@3]/__N.G>!`CH"?3__[CYW@0(Z/_S__^XKMX$".CU\___N`7?!`CHZ_/_
M_[@/WP0(Z.'S__^X&=\$".C7\___N+?>!`CHS?/__[@CWP0(Z,/S__^X+-\$
M".BY\___N#??!`CHG_/__X7`=`R)PK@/WP0(Z&_W__^X2-\$".B%\___A<!T
M#(G"N%K?!`CH5??__[AEWP0(Z&OS__^%P'0OB<*XKMX$".@[]___NI'?!`BX
MZ=X$".@L]___BT0D+&4S!10```!U28/$-%Y?PY"X==\$".@N\___A<!T$HG"
MN`7?!`CH_O;__^O!C70F`(UT)!N_AM\$"+D*````\Z9UJXU4)"6X!=\$".C8
M]O__ZYOHH<C__Y"#[`RA0`$%"(/X_W0+@\0,PXVT)@````"X!=\$".C.\O__
MB<(QP(72=`\/MA*$TG0(,<"`^C`/E<"C0`$%"(/$#,.-M"8`````C;PG````
M`(/L'.A8R/__B00DZ+#'__^%P'0,BP"#Q!S#C;8`````,<#K\HVV`````(V_
M`````%575E.[G=\$"(/L7(M\)'"-="0XQT0D-)W?!`C'1"0XD]\$",=$)#R@
MWP0(QT0D0);?!`C'1"1$F]\$",=$)$BMWP0(QT0D3`````#K'&:0B7PD!(D$
M).@$Q___A<!T.(/&!(M>_(7;="6)V.C_\?__A<")Q70%@#@`==2)V(/&!(GZ
MZ,CU__^+7OR%VW7;@\1<6UY?7<.0B3PDZ.#(__^)+"2)1"0LZ-3(__^+5"0L
MC40"`HD$).A4R/__B6PD&,=$)!3$W@0(B7PD$,=$)`SEWP0(QT0D"/_____'
M1"0$`0```(D$)(E$)"SHL,K__XM4)"R)V.A5]?__Z6#___]55U93@>Q,@0``
M9:$4````B80D/($``#'`N*[>!`B+G"1@@0``QT0D:,3?!`C'1"1LK-X$",=$
M)'``````QT0D4%K?!`C'1"144]\$",=$)%C)WP0(QT0D7'#?!`C'1"1@T=\$
M",=$)&0`````QT0D=+C?!`C'1"1XU=\$",=$)'P`````Z.;P__^%P'0)@#@`
M#X41!```Z#3^__^%P(G%#X0A!```#[95`(32="J(5"0\Z-G)__\/ME0D/(GI
M9I"+,`^^TO8$5@AU`\8!7X/!`0^V$832=>B-?"14N%K?!`CK#Y"-="8`@\<$
MBT?\A<!T+NAY\/__A<")QG3K@#@`=.;HJ?/__X7`=-V)-"3H[<?__X7`B<=U
M4(VT)@````"+="1H,?^%]G0_@#X`N`$```!T-8G'ZQB+=+QHA?8/A&P!``"#
MQP&`/@`/A&`!``")\.A9\___A<!TW8DT).B=Q___A<!TT8G'B3PDZ`_'__^)
M+"2)QN@%Q___C;0&!`0``(DT).B&QO__B6PD',=$)!C>WP0(QT0D%,;>!`B)
M?"00QT0D#./?!`B)1"1(QT0D"/_____'1"0$`0```(D$).C:R/__BT0D2,=$
M)`3``0``B00DZ!;'__^#^/\/A(4```"A*%T%"(D$).A0R/__QP0D`P```(/`
M7(E$)`B+1"1(B40D!.A%R/__A<`/A*4```"+1"1(,>V)1"00BP/'1"0(G.`$
M",=$)`0!````B40D#*$D704(B00DZ,#'__^+E"0\@0``93,5%````(GH#X72
M"0``@<1,@0``6UY?7<.-M"8`````Z+/&__^+`(/X$0^$:____XE$)!2+1"1(
M,>V)1"00BP/'1"0(8.`$",=$)`0!````B40D#*$D704(B00DZ%?'___KE9"-
M="8`,?_ILO[__Y"A*%T%"(D$).A[Q___BT!L)0#P```]`$````^%.____Z$H
M704(B00DZ%O'__^+>'3H0\3__SG'#X4>____H2A=!0B)!"3H/L?__XM`;"7_
M`0``/<`!```/A?[^__^)-"3H\\3__XG%N);?!`CH1^[__X7`#X3>`0``B00D
MZ,?%__^)1"0$BP.)!"3HF?;__X7`B40D0`^$O`$``(M$)$")!"3H(<7__X/X
M`WXTBU0D0+_LWP0(N04```"-=`+\\Z9U'H/X!`^$D`<``(M\)$"`?`?[+P^$
M@0<``(VV`````.CC^O__A<!U((M$)$#'1"0$`````(D$).CKQ/__A<")1"1,
M#X59`0``NI'?!`BX!=\$".B`\?__,=OH"<3__\=$)!POX`0(QT0D%,;>!`C'
M1"0,"N`$",=$)`C_____QT0D!`$```")1"08BT0D2(DL)(E$)!#HC<;__XMT
M)$CK58VT)@````#H^\3__X,X$759Z+'#__^#PP''1"0@+^`$"(E<)!S'1"04
MQMX$"(ET)!#'1"0,&.`$"(E$)!C'1"0(_____\=$)`0!````B2PDZ#+&___'
M1"0$P`$``(DL).ARQ/__@_C_=)V+1"1(B00DZ"'"__^)ZKBNW@0(Z+7P__^)
M+"3H7?K__^F8_?__B00DB40D/.A,^O__BT0D/(D$).A`Q/__B<7I>?W__[X!
M````N+C?!`CK$)"-="8`BT2T=(/&`87`="+HB.S__X7`=.R`.`"0=.:)!"3H
M!L3__X7`=-J)Q>FA^___O;W?!`CIR?O__XL#B40D0.DY_O__QT0D#`(```#'
M1"0$[O___\=$)`C_____B00DZ);"__^+1"1,C90D@````,=$)`@&````B50D
M!(D$).@GP?__@+PD@`````!U#H"\)($```!##X0A!@``BT0D3,=$)`P`````
MQT0D!`````#'1"0(`````(D$).@[PO__QX0D@(````$C16?'A"2$@```````
M`,>$)(B```")J\WOQX0DC(````````#'A"20@```_MRZF,>$))2`````````
MQX0DF(```'94,A#'A"2<@````````,>$)*"```#PX=+#QX0DI(````````#'
MA"2H@````````,>$)*R`````````QX0DL(````````#'A"2T@````````,>$
M)/B`````````C;8`````BT0D3(V4)(````#'1"0(`(```(E4)`2)!"3H(<#_
M_X7`B<,/CN\!``"+A"2H@```B=^)WHN4)*R```#!_Q^)1"1`B=B)5"1$P>`#
M`T0D0(-\)$0`=P8Y1"1`=A"#A"2P@````8.4)+2`````B80DJ(```(N$)/B`
M```/K/X=P>\=`;0DL(```!&\)+2```"-E"2`````A<#'A"2L@````````(E4
M)$!T7[Y`````*<8Y\XV\)+B````/3O,!^(ET)`B)5"0$B00DZ+*___^+A"3X
M@````?"#^$")A"3X@```#X49____C90D@````"GS`?*-A"2`@```B50D0.@.
MQO__C;8`````@_L_#X[8````BW0D0(G?D(L&@^]`B80DN(```(M&!(F$)+R`
M``"+1@B)A"3`@```BT8,B80DQ(```(M&$(F$),B```"+1A2)A"3,@```BT88
MB80DT(```(M&'(F$)-2```"+1B")A"38@```BT8DB80DW(```(M&*(F$)."`
M``"+1BR)A"3D@```BT8PB80DZ(```(M&-(F$).R```"+1CB)A"3P@```BT8\
M@\9`B80D](```(V$)("```#H1\7__X/_/P^/1O___X/K0(G:P>H&C4(!P>`&
M`40D0,'B!BG3BWPD0(V$)+B```#'1"0,1````(E<)`B)!"2)?"0$Z.2___^)
MG"3X@```Z>C]__^+1"1,B00DZ/S!__^+A"2P@```BYPDJ(```(NT)*R```"+
ME"2T@```B40D0(G8#ZSP`X/@/XE4)$2-4`&#^CC&A`2X@```@`^/J`(``+HW
M````*<*-A`2Y@```B50D",=$)`0`````B00DZ!G`__^+5"1$BT0D0(B<)/>`
M```/K-`8BU0D1(B$)/"```"+1"1`#ZS0$(M4)$2(A"3Q@```BT0D0`^LT`B(
MA"3R@```#[9$)$"(A"3S@```B=@/K/`8B(0D](```(G8#ZSP$(B$)/6```")
MV#';#ZSP"(B$)/:```"-A"2`@```Z`C$__^+M"2`@```B[PDA(```(GPB?(/
MK/@8B<&(A"0H@0``B?`/K/@0B(0D*8$``(GPB[0DB(````^L^`B+O"2,@```
MB(0D*H$``(B4)"N!``")\`^L^!B(A"0L@0``B?`/K/@0B(0D+8$``(GP#ZSX
M"(N\))2```"(A"0N@0``B?"+M"20@```B(0D+X$``(GPB?(/K/@8B(0D,($`
M`(GP#ZSX$(B$)#&!``")\(NT))B````/K/@(B[PDG(```(B$)#*!``"(E"0S
M@0``B?`/K/@8B(0D-($``(GP#ZSX$(B$)#6!``")\`^L^`B+O"2D@```B(0D
M-H$``(GPB[0DH(```(B$)#>!``")\(GR#ZSX&(B$)#B!``")\`^L^!"(A"0Y
M@0``B?`/K/@(B(0D.H$``(VT)/^```")R(B4)#N!``#I"@```&:0#[:$'"B!
M```/ML")1"00C01>@\,!QT0D#`7@!`C'1"0(_____\=$)`0!````B00DZ-N_
M__^#^Q1UQL:$)">!````QT0D'"_@!`B)="08BT0D2,=$)!3&W@0(QT0D#/;?
M!`C'1"0(_____XE$)!#'1"0$`0```(DL).B2O___Z7#Y__^+6P2%VP^$>OC_
M_XD<).A:O?__@_@##X9I^/__C70#_+_QWP0(N04```#SI@]%7"1`B5PD0.E+
M^/__NC\````IPHV$!+F```")5"0(QT0D!`````")!"3H<;W__XV$)("```#H
MU<'__XV4)+B```"Y#@```#'`B=?SJ^DU_?__@+PD@@```$$/A='Y__^`O"2#
M````0P^%P_G__X"\)(0```!(#X6U^?__@+PDA0```$4/A:?Y__^+1"1,QT0D
M#`(```#'1"0$QO___\=$)`C_____B00DZ.*[__^+1"1,C90D@````(E4)`3'
M1"0(*0```(D$).ASNO__C90D@````,=$)!POX`0(B50D&.FY_O__C78`Z/.Z
M__^-=@!55U93@^P<H2A=!0B)!"3H_+W__\:`^0(```&XZ=X$".@;Y?__A<!T
M"8`X,0^$G@(``.AY\/__H2A=!0B)!"3HS+W__\=$)`P+````QT0D"`$```#'
M1"0$*>`$"(D$).B,N___A<`/A,0```"+0`PQ]HMH&*&$;04(@_@!#XZC````
MNP$```#K,8VT)@````"+1PR)1"0$H8!M!0B+!)B)!"3HF;G__X7`=76AA&T%
M"(/#`8/&`3G8?FNA*%T%"(D$).A)O?__QT0D#`````")="0(B6PD!(D$).BA
MO/__A<!T/8LX]D<)!'6EH2A=!0B)!"3H&+W__\=$)`P"````QT0D"`````")
M?"0$B00DZ$RZ___I>O___XVT)@````"AA&T%"(U0_SGR#X1``0``H2A=!0B)
M!"3HT[S__\=$)`P$````QT0D"`$```#'1"0$+N`$"(D$).B3NO__A<")PW0U
MBT`,BS"A*%T%"(D$).B;O/__QT0D"##@!`B)="0$B00DZ,>Y__^+0PR+&/9#
M"D`/A1@!``"A*%T%"(D$).AKO/__QT0D#`0```#'1"0(`0```,=$)`0UWP0(
MB00DZ"NZ__^%P(G#=#:XM]X$".AKX___A<")Q@^$>0$``(M##(LXH2A=!0B)
M!"3H'[S__XET)`B)?"0$B00DZ$^Y__^A*%T%"(D$).@"O/__QH#Y`@```*$H
M704(B00DZ.Z[___'@'`$````````N*[>!`CH"N/__X7`HXAM!0@/A*4```#'
M1"0$P`$``(D$).AMNO__@_@1=`Z%P'0*@_C_D`^%@0$``(/$'%M>7UW#9I"#
M^`$/CK?^__^[`0```&:0H2A=!0B#PP&)!"3H@+O__XEL)`2)!"3H!+C__SD=
MA&T%"'_<Z8?^__^-M"8`````H2A=!0B)!"3H4[O__XE<)`2)!"3H5[K__^G*
M_O__9I"`>`$`#X1=_?__C;8`````Z4W]__^-=@"A@&T%"(D$).C;\/__A<"C
MB&T%"`^$V0```(M##(L]@&T%"(LP]D8)!'1LBT8,B7PD!(D$).@.N/__B<:+
M0PR+&/9#"01T?HM##(E$)`BA@&T%"(ET)`R+`,<$)!3A!`B)1"0$Z#^Y__^-
MM"8`````H8!M!0B+.(M##(LPH2A=!0B)!"3HG[K__XGZB?#HEN?__^F"_O__
MH2A=!0B)!"3HA+K__\=$)`P"````QT0D"`````")="0$B00DZ+BW___I:?__
M_Z$H704(B00DZ%:Z___'1"0,`@```,=$)`@`````B5PD!(D$).B*M___Z5?_
M___'!"3PX`0(Z*FX__^)1"0,H8AM!0B)1"0(H8!M!0B+`,<$)#SA!`B)1"0$
MZ(6X__^0C70F`%93@^P4BW0D((DT).B/Z___#[80B<.$TG07C4`!C78`@/HO
M#T38@\`!#[90_X32=>_H"N[__X7`="&%]HUT)@!T&8`^`'04QT0D!-[?!`B)
M'"3HR;7__SG8=`:#Q!1;7L.#Q!2)\%M>Z9/B__^-=@"#[!RA*%T%"(D$).B`
MN?__QT0D!/____^)!"3HX+;__Z$H704(B00DZ&.Y___'1"0(`````,=$)`00
MO@0(B00DZ!NY__^#Q!S#D)"0D)"0D%/H-````('#KB(``(/L$(N#,`$``(E$
M)`R+1"0@B40D"(M$)!R)1"0$BT0D&(D$).B+MO__@\006\.+'"3#D)!55U93
MZ/'___^!PVLB``"#[!R+;"0PC;L0____Z+NT__^-@Q#___\IQ\'_`H7_="DQ
M]HVV`````(M$)#B)+"2)1"0(BT0D-(E$)`3_E+,0____@\8!.?YUWX/$'%M>
M7UW#ZPV0D)"0D)"0D)"0D)"0\\.0D)"0D)"0D)"0D)"0D%6)Y5.#[`2A!/\$
M"(/X_W03NP3_!`AFD(/K!/_0BP.#^/]U](/$!%M=PY"04X/L".@`````6X'#
MOR$``.B_NO__@\0(6\,```,````!``(`)7,O)7,`+W!R;V,O<V5L9B]E>&4`
M<&5R;'AS:2YC`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA
M;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E<P`N`%!!4E]414U0`%!!4E]04D]'
M3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),24\`4$%2
M7TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`
M4$%27T-!0TA%`%!!4E]!4D=#`%!!4E]!4D=67S``4$%27T=,3T)!3%]$14)5
M1P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!4E]'3$]"04Q?5$5-
M4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!,24)0051(`$193$1?
M3$E"4D%265]0051(`%-(3$E"7U!!5$@`55-%4@!365-414T`+W1M<`!414U0
M1$E2`%1-4`!54T523D%-10!P87(M`"5S)7,E<R5S`'!A<FP`+G!A<@`E<R5S
M8V%C:&4M)7,E<P`E,#)X`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E
M<P!!4D=6`!@`<&5R;``M90`M+0``7U]%3E9?4$%27T-,14%.7U\@("`@("`@
M("`@("`@("``````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T
M;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z('!R:79A=&4@<W5B9&ER
M96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T
M<GD@>6]U<B!O<&5R871I;VXI"@``56YA8FQE('1O(&-R96%T92!C86-H92!D
M:7)E8W1O<GD`````)7,Z(&5X96-U=&EO;B!O9B`E<R!F86EL960@*&5R<FYO
M/25I*0H``"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C
M=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``````````````````(#____/
M00$;`SOX````'@````"Q__\4`0``8+7__X`%````N/__.`$``'#;__]X`0``
M(-S__\P!```PW/__Y`$``(#<__\(`@``\-W__S0"``!@W___8`(```#@__^8
M`@``\.'__]@"````X___!`,``$#C__\<`P``H./__S0#``"`Y/__7`,``)#D
M__]P`P``8.;__[`#``"0YO__Q`,``)#G__\`!```,.G__S`$``"`Z?__4`0`
M`+#I__]L!```L.K__ZP$``#@]O__\`0``/#Z__\P!0``8/O__V@%``"P^___
MK`4``.K[___,!0``\/O__^`%``!@_/__'`8``!0``````````7I2``%\"`$;
M#`0$B`$``"`````<````Y*___V`$````#@A&#@Q*#PMT!'@`/QH[*C(D(CP`
M``!`````P+;__W`C````00X(A0)##@R'`T0.$(8$00X4@P5(#O@%`UHC#A1!
M#A##00X,QD$.",=!#@3%``!0````@````/#9__^A`````$$."(4"00X,AP-!
M#A"&!$$.%(,%10Y``E<*#A1!#A##00X,QD$.",=!#@3%1`MP#A1%PPX00<8.
M#$''#@A!Q0X$```4````U````$S:__\0`````$,.($P.!``@````[````$3:
M__]0`````$$."(,"10X@`D@."$$.!,,````H````$`$``'#:__]M`0```$$.
M"(8"00X,@P-##B`#90$.#$$.",-!#@3&`"@````\`0``M-O__V(!````1@Z@
M`4N'`U>%`H8$@P5G"@X$Q<?&PT$+````-````&@!``#XW/__EP````!!#@B&
M`D,.#(,#10X@:PH.#$,.",-!#@3&2`L"4@X,0\,."$'&#@0\````H`$``&#=
M___A`0```$$."(4"00X,AP-!#A"&!$,.%(,%10Y0`ND*#A1!#A##00X,QD$.
M",=!#@3%2`L`*````.`!```0W___!`$```!&#L`@2X<#28,%284":88$`H0*
M#@3%Q\;#2`L4````#`(``/3?__\T`````$,.('`.!``4````)`(``!S@__]9
M`````$,.,`)5#@0D````/`(``&3@___>`````$8.P$!)@P1+A@-6AP("J`H.
M!,?&PT$+$````&0"```<X?__!0`````````\````>`(``!CA___$`0```$$.
M"(4"00X,AP-!#A"&!$$.%(,%1@[@(`)E"@X400X0PT$.#,9!#@C'00X$Q4$+
M$````+@"``"HXO__(P`````````X````S`(``,3B___R`````$$."(,"0PX@
M`E0*#@A!#@3#1PL"3PH."$;##@1#"U`*#@A!#@3#10L````L````"`,``(CC
M__^?`0```$$."(<"00X,A@-##D`#3P$*#@Q!#@C&00X$QT(+```<````.`,`
M`/CD__]"`````$,.$$T*#@1("VD.!````!@```!8`P``*.7__R0`````0PX@
M5@H.!$<+```\````=`,``#SE__\``0```$$."(4"00X,AP-!#A"&!$$.%(,%
M2`YP`H8*#A1!#A##00X,QD$.",=!#@3%0@L`0````+0#``#\Y?__+0P```!!
M#@B%`D$.#(<#00X0A@1!#A2#!48.X(("`U(""@X400X0PT$.#,9!#@C'00X$
MQ4@+```\````^`,``.CQ__\+!````$$."(4"00X,AP-!#A"&!$$.%(,%0PXP
M`V(""@X400X0PT$.#,9!#@C'00X$Q4,+-````#@$``"X]?__;0````!!#@B&
M`D$.#(,#0PX@`ED*#@Q!#@C#00X$QD$+0PX,0PX(PT$.!,84````<`0``/#U
M__])`````$,.(`)%#@0H````B`0``-BO___B`0```$$."(4"0@T%7(,$A@,#
M9P$*PT'&00P$!,5!"QP```"T!```_/7__SH`````00X(@P).#AAI#@A!#@3#
M$````-0$```6]O__!``````````X````Z`0```CV__]A`````$$."(4"00X,
MAP-!#A"&!$$.%(,%3@XP`DH.%$$.$,-!#@S&00X(QT$.!,40````)`4``#SV
M__\"````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````/____\`````_____P``````````
M`0````$````!````SP$```$````>`@``#````%R2!`@-````+-X$"/7^_V^L
M@00(!0```)2)!`@&````!(,$"`H```#\!```"P```!`````5``````````,`
M``#T_P0(`@```"@"```4````$0```!<````TD`0($0````20!`@2````,```
M`!,````(````_O__;V2/!`C___]O`@```/#__V^0C@0(````````````````
M`````````````````````````````````````````````````````!C_!`@`
M`````````*:2!`BVD@0(QI($"-:2!`CFD@0(]I($"`:3!`@6DP0()I,$"#:3
M!`A&DP0(5I,$"&:3!`AVDP0(AI,$"):3!`BFDP0(MI,$",:3!`C6DP0(YI,$
M"/:3!`@&E`0(%I0$"":4!`@VE`0(1I0$"%:4!`AFE`0(=I0$"(:4!`B6E`0(
MII0$"+:4!`C&E`0(UI0$".:4!`CVE`0(!I4$"!:5!`@FE00(-I4$"$:5!`A6
ME00(9I4$"':5!`B&E00(EI4$"*:5!`BVE00(QI4$"-:5!`CFE00(]I4$"`:6
M!`@6E@0()I8$"#:6!`A&E@0(5I8$"&:6!`AVE@0(AI8$"):6!`BFE@0(MI8$
M",:6!`C6E@0(YI8$"```````````````````````````````````````````
M````````````````_____P`````````````````````````````````````C
M(2]U<W(O8FEN+W!E<FP*979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D
M,"`D>S$K(B1`(GTG"B`@("!I9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O
M;64@<VAE;&P*"G!A8VMA9V4@7U]P87)?<&P["@HC("TM+2!4:&ES('-C<FEP
M="!M=7-T(&YO="!U<V4@86YY(&UO9'5L97,@870@8V]M<&EL92!T:6UE("TM
M+0HC('5S92!S=')I8W0["@HC;&EN92`Q-3@*"FUY("@D<&%R7W1E;7`L("1P
M<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]
M*2!["B`@("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z
M.D)A<V5N86UE.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@;7D@)'1O
M<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["B`@
M("!O=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["B`@
M("!&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@
M.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*("`@(')M9&ER("1P87)?=&5M<#L*
M("`@(",@1&]N)W0@<F5M;W9E('1O<&1I<B!B96-A=7-E('1H:7,@8V%U<V5S
M(&$@<F%C92!W:71H(&]T:&5R(&%P<',*("`@(",@=&AA="!A<F4@=')Y:6YG
M('1O('-T87)T+@H*("`@(&EF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-
M4U=I;C,R)RD@>PH@("`@("`@(",@4V]M971H:6YG('=E;G0@=W)O;F<@=6YL
M:6YK:6YG('1H92!T96UP;W)A<GD@9&ER96-T;W)Y+B`@5&AI<PH@("`@("`@
M(",@='EP:6-A;&QY(&AA<'!E;G,@;VX@<&QA=&9O<FUS('1H870@9&ES86QL
M;W<@=6YL:6YK:6YG('-H87)E9`H@("`@("`@(",@;&EB<F%R:65S(&%N9"!E
M>&5C=71A8FQE<R!T:&%T(&%R92!I;B!U<V4N(%5N;&EN:R!W:71H(&$@8F%C
M:V=R;W5N9`H@("`@("`@(",@<VAE;&P@8V]M;6%N9"!S;R!T:&4@9FEL97,@
M87)E(&YO(&QO;F=E<B!I;B!U<V4@8GD@=&AI<R!P<F]C97-S+@H@("`@("`@
M(",@1&]N)W0@9&\@86YY=&AI;F<@;VX@5VEN9&]W<R!B96-A=7-E(&]U<B!P
M87)E;G0@<')O8V5S<R!W:6QL"B`@("`@("`@(R!T86ME(&-A<F4@;V8@8VQE
M86YI;F<@=&AI;F=S('5P+@H*("`@("`@("!M>2`D=&UP(#T@;F5W($9I;&4Z
M.E1E;7`H"B`@("`@("`@("`@(%1%35!,051%(#T^("=T;7!86%A86"<L"B`@
M("`@("`@("`@($1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P
M9&ER*2P*("`@("`@("`@("`@4U5&1DE8(#T^("<N8VUD)RP*("`@("`@("`@
M("`@54Y,24Y+(#T^(#`L"B`@("`@("`@*3L*"B`@("`@("`@<')I;G0@)'1M
M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"B`@
M(')M("UR9B`G)'!A<E]T96UP)PH@("!I9B!;(%PA("UD("<D<&%R7W1E;7`G
M(%T[('1H96X*("`@("`@(&)R96%K"B`@(&9I"B`@('-L965P(#$*("`@>#U@
M97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B
M)PHB.PH@("`@("`@("`@("!C:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PH@
M("`@("`@(&UY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L
M;"`R/B8Q("8G.PH@("`@("`@(&-L;W-E("1T;7`["B`@("`@("`@<WES=&5M
M*"1C;60I.PH@("`@("`@(&]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R
M;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"B`@("`@("`@("`@("`N("1T
M;7`M/F9I;&5N86UE*3L*("`@('T*?2!]"@I"14=)3B!["B`@("!);G1E<FYA
M;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"
M3T]4.PH*("`@(&5V86P@>PH*7W!A<E]I;FET7V5N=B@I.PH*:68@*&5X:7-T
M<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!4D=67S!]("D@>PH@
M("`@0$%21U8@/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.
M5GM005)?05)'0WT@+2`Q*3L*("`@("0P(#T@)$5.5GM005)?05)'5E\P?3L*
M?0IE;'-E('L*("`@(&9O<B`H:V5Y<R`E14Y6*2!["B`@("`@("`@9&5L971E
M("1%3E9[)%]](&EF("]>4$%27T%21U9?+SL*("`@('T*?0H*;7D@)'%U:65T
M(#T@(21%3E9[4$%27T1%0E5'?3L*"B,@9FEX("1P<F]G;F%M92!I9B!I;G9O
M:V5D(&9R;VT@4$%42`IM>2`E0V]N9FEG(#T@*`H@("`@<&%T:%]S97`@("`@
M/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"B`@("!?97AE("`@
M("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE
M>&4G(#H@)R<I+`H@("`@7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN
M?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*"E]S971?<')O9VYA;64H*3L*7W-E
M=%]P87)?=&5M<"@I.PH*(R!-86=I8R!S=')I;F<@8VAE8VMI;F<@86YD(&5X
M=')A8W1I;F<@8G5N9&QE9"!M;V1U;&5S('M[>PIM>2`H)'-T87)T7W!O<RP@
M)&1A=&%?<&]S*3L*>PH@("`@;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@
M>WT["@H@("`@(R!#:&5C:R!F:6QE('1Y<&4L(&=E="!S=&%R="!O9B!D871A
M('-E8W1I;VX@>WM["B`@("!O<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@
M;&%S=#L*("`@(&)I;FUO9&4H7T9(*3L*"B`@("!M>2`D8G5F.PH@("`@<V5E
M:R!?1D@L("TX+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#@["B`@("!L87-T
M('5N;&5S<R`D8G5F(&5Q(")<;E!!4BYP;5QN(CL*"B`@("!S965K(%]&2"P@
M+3$R+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("!S965K(%]&2"P@
M+3$R("T@=6YP86-K*").(BP@)&)U9BDL(#(["B`@("!R96%D(%]&2"P@)&)U
M9BP@-#L*"B`@("`D9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*("`@(",@
M?7U]"@H@("`@(R!%>'1R86-T:6YG(&5A8V@@9FEL92!I;G1O(&UE;6]R>2![
M>WL*("`@(&UY("5R97%U:7)E7VQI<W0["B`@("!W:&EL92`H)&)U9B!E<2`B
M1DE,12(I('L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@("!R
M96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@(&UY
M("1F=6QL;F%M92`]("1B=68["B`@("`@("`@;W5T<RAQ<2A5;G!A8VMI;F<@
M9FEL92`B)&9U;&QN86UE(BXN+BDI.PH@("`@("`@(&UY("1C<F,@/2`H("1F
M=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968[
M"B`@("`@("`@;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_
M.BXJ+RD_*"XJ*2A<+BXJ*7PI.PH*("`@("`@("!R96%D(%]&2"P@)&)U9BP@
M-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD[
M"@H@("`@("`@(&EF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_
M.G!M?'!L?&EX?&%L*20O:2D@>PH@("`@("`@("`@("!M>2`H)&]U="P@)&9I
M;&5N86UE*2`](%]T96UP9FEL92@D97AT+"`D8W)C*3L*("`@("`@("`@("`@
M:68@*"1O=70I('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@
M("`@("`@("`@("`@("!P<FEN="`D;W5T("1B=68["B`@("`@("`@("`@("`@
M("!C;&]S92`D;W5T.PH@("`@("`@("`@("`@("`@8VAM;V0@,#<U-2P@)&9I
M;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*("`@("`@("`@
M("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN
M86UE.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H("1F=6QL;F%M92`]?B!M
M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["B`@
M("`@("`@("`@(",@<VAO=6QD(&)E(&UO=F5D('1O(%]T96UP9FEL92@I"B`@
M("`@("`@("`@(&UY("1F:6QE;F%M92`]("(D14Y6>U!!4E]414U0?2\D8F%S
M96YA;64D97AT(CL*("`@("`@("`@("`@;W5T<R@B4TA,24(Z("1F:6QE;F%M
M95QN(BD["B`@("`@("`@("`@(&]P96X@;7D@)&]U="P@)SXG+"`D9FEL96YA
M;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@
M("`@("`@("!P<FEN="`D;W5T("1B=68["B`@("`@("`@("`@(&-L;W-E("1O
M=70["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D<F5Q
M=6ER95]L:7-T>R1F=6QL;F%M97T@/0H@("`@("`@("`@("`D4$%2.CI(96%V
M>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*("`@("`@("`@("`@("`@
M(&)U9B`]/B`D8G5F+`H@("`@("`@("`@("`@("`@8W)C(#T^("1C<F,L"B`@
M("`@("`@("`@("`@("!N86UE(#T^("1F=6QL;F%M92P*("`@("`@("`@("`@
M?3L*("`@("`@("!]"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("!]
M"B`@("`C('U]?0H*("`@(&QO8V%L($!)3D,@/2`H<W5B('L*("`@("`@("!M
M>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["@H@("`@("`@(')E='5R;B!I9B!R
M968@)&UO9'5L92!O<B`A)&UO9'5L93L*"B`@("`@("`@;7D@)&9I;&5N86UE
M(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PH@("`@
M("`@("`@("!M>2`D:V5Y.PH@("`@("`@("`@("!F;W)E86-H("AK97ES("5R
M97%U:7)E7VQI<W0I('L*("`@("`@("`@("`@("`@(&YE>'0@=6YL97-S("]<
M421M;V1U;&5<120O.PH@("`@("`@("`@("`@("`@)&ME>2`]("1?.R!L87-T
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["B`@("`@("`@?2!O<B!R971U
M<FX["@H@("`@("`@("1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA
M;64O)&UO9'5L92(["@H@("`@("`@(&EF("@D14Y6>U!!4E]#3$5!3GT@86YD
M(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["B`@("`@("`@("`@(&UY("1F
M:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["B`@("`@("`@
M("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<')I;G0@)&9H("1F:6QE
M;F%M92T^>V)U9GT["B`@("`@("`@("`@('-E96LH)&9H+"`P+"`P*3L*("`@
M("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@("!]"B`@("`@("`@96QS92![
M"B`@("`@("`@("`@(&UY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I;&4H)RYP
M;2<L("1F:6QE;F%M92T^>V-R8WTI.PH@("`@("`@("`@("!I9B`H)&]U="D@
M>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@
M("`@('!R:6YT("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@
M("`@(&-L;W-E("1O=70["B`@("`@("`@("`@('T*("`@("`@("`@("`@;W!E
M;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B
M:6YM;V1E*"1F:"D["B`@("`@("`@("`@(')E='5R;B`D9F@["B`@("`@("`@
M?0H*("`@("`@("!D:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@
M9FEN9"`D;6]D=6QE(5QN(CL*("`@('TL($!)3D,I.PH*("`@(",@3F]W(&QO
M860@86QL(&)U;F1L960@9FEL97,@>WM["@H@("`@(R!I;FET:6%L:7IE('-H
M87)E9"!O8FIE8W0@<')O8V5S<VEN9PH@("`@<F5Q=6ER92!84TQO861E<CL*
M("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@0V%R<#HZ2&5A
M=GD["B`@("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(%!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"B`@("`C(&YO=R!L970G<R!T<GD@
M9V5T=&EN9R!H96QP97(@;6]D=6QE<R!F<F]M('=I=&AI;@H@("`@<F5Q=6ER
M92!)3SHZ1FEL93L*"B`@("`C(&QO860@<F5S="!O9B!T:&4@9W)O=7`@:6X*
M("`@('=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E
M7VQI<W0I6S!=*2!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@
M7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!U;FQE<W,@
M*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*
M("`@("`@("`@("`@(R!R97%U:7)E(&UO9'5L97,L(&1O(&]T:&5R(&5X96-U
M=&%B;&4@9FEL97,*("`@("`@("`@("`@:68@*"1F:6QE;F%M92`]?B`O7"YP
M;6,_)"]I*2!["B`@("`@("`@("`@("`@("!R97%U:7)E("1F:6QE;F%M93L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@
M("`@(",@4VMI<"!!8W1I=F53=&%T92=S('-I=&5C=7-T;VUI>F4N<&P@9FEL
M93H*("`@("`@("`@("`@("`@(&1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N
M86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M
M97T["B`@("!]"@H@("`@(R!]?7T*"B`@("!L87-T('5N;&5S<R`D8G5F(&5Q
M(")02UPP,#-<,#`T(CL*("`@("1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@
M-#L*?0HC('U]?0H*(R!!<F=U;65N="!P<F]C97-S:6YG('M[>PIM>2!`<&%R
M7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE
M*3L*"F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2
M155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0H*)'%U:65T(#T@,"!U
M;FQE<W,@)$5.5GM005)?1$5"54=].PHC($1O;B=T('-W86QL;W<@87)G=6UE
M;G1S(&9O<B!C;VUP:6QE9"!E>&5C=71A8FQE<R!W:71H;W5T("TM<&%R+6]P
M=&EO;G,*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M
M;W!T:6]N<R<@)B8@<VAI9G0I*2!["B`@("!M>2`E9&ES=%]C;60@/2!Q=R@*
M("`@("`@("!P("`@8FQI8E]T;U]P87(*("`@("`@("!I("`@:6YS=&%L;%]P
M87(*("`@("`@("!U("`@=6YI;G-T86QL7W!A<@H@("`@("`@(',@("!S:6=N
M7W!A<@H@("`@("`@('8@("!V97)I9GE?<&%R"B`@("`I.PH*("`@(",@:68@
M=&AE(&%P<"!I<R!I;G9O:V5D(&%S(")A<'!N86UE("TM<&%R+6]P=&EO;G,@
M+2UR975S92!04D]'4D%-($!04D]'7T%21U8B+`H@("`@(R!U<V4@=&AE(&%P
M<"!T;R!R=6X@=&AE(&=I=F5N('!E<FP@8V]D92!I;G-T96%D(&]F(&%N>71H
M:6YG(&9R;VT@=&AE"B`@("`C(&%P<"!I='-E;&8@*&)U="!S=&EL;"!S970@
M=7`@=&AE(&YO<FUA;"!A<'`@96YV:7)O;FUE;G0@86YD($!)3D,I"B`@("!I
M9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PH@("`@("`@
M('-H:69T($!!4D=6.PH@("`@("`@("1%3E9[4$%27T%04%]2155317T@/2!S
M:&EF="!`05)'5CL*("`@('T*("`@(&5L<V4@>R`C(&YO<FUA;"!P87)L(&)E
M:&%V:6]U<@H*("`@("`@("!M>2!`861D7W1O7VEN8SL*("`@("`@("!W:&EL
M92`H0$%21U8I('L*("`@("`@("`@("`@)$%21U9;,%T@/7X@+UXM*%M!24U/
M0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*"B`@("`@("`@("`@(&EF("@D
M,2!E<2`G22<I('L*("`@("`@("`@("`@("`@('!U<V@@0&%D9%]T;U]I;F,L
M("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G
M32<I('L*("`@("`@("`@("`@("`@(&5V86P@(G5S92`D,B(["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=!)RD@>PH@("`@("`@
M("`@("`@("`@=6YS:&EF="!`<&%R7V%R9W,L("0R.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G3R<I('L*("`@("`@("`@("`@
M("`@("1O=70@/2`D,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I
M9B`H)#$@97$@)V(G*2!["B`@("`@("`@("`@("`@("`D8G5N9&QE(#T@)W-I
M=&4G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G
M0B<I('L*("`@("`@("`@("`@("`@("1B=6YD;&4@/2`G86QL)SL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)W$G*2!["B`@("`@
M("`@("`@("`@("`D<75I970@/2`Q.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&5L<VEF("@D,2!E<2`G3"<I('L*("`@("`@("`@("`@("`@(&]P96X@
M)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G
M.B`D(2(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q
M("=4)RD@>PH@("`@("`@("`@("`@("`@)&-A8VAE7VYA;64@/2`D,CL*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@<VAI9G0H0$%21U8I.PH*("`@("`@
M("`@("`@:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["B`@("`@("`@
M("`@("`@("!D96QE=&4@)$5.5GLG4$%27U1%35`G?3L*("`@("`@("`@("`@
M("`@(&EN:71?:6YC*"D["B`@("`@("`@("`@("`@("!R97%U:7)E(%!!4CHZ
M1&ES=#L*("`@("`@("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@
M=6YL97-S($!!4D=6.PH@("`@("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH)%\I(&9O<B!`05)'5CL*("`@("`@("`@("`@("`@(&5X:70["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@('5N<VAI9G0@0$E.0RP@
M0&%D9%]T;U]I;F,["B`@("!]"GT*"B,@6%A8("TM(&%D9"`M+7!A<BUD96)U
M9R!S=7!P;W)T(0H*(R!]?7T*"B,@3W5T<'5T(&UO9&4@*"U/*2!H86YD;&EN
M9R![>WL*:68@*"1O=70I('L*("`@('L*("`@("`@("`C;&]C86P@)$E.0WLG
M0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@
M("`@(')E<75I<F4@24\Z.D9I;&4["B`@("`@("`@<F5Q=6ER92!!<F-H:79E
M.CI::7`["B`@("!]"@H@("`@;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*("`@
M(&UY("1Z:7`["@H*("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O
M<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P
M87(G.B`D(2(["B`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@(&)L97-S
M*"1F:"P@)TE/.CI&:6QE)RD["@H@("`@("`@("1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL*("`@("`@("`H("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D
M9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"B`@("`@("`@
M("`@(&]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*("`@('T*"@H@
M("`@;7D@)65N=B`](&1O('L*("`@("`@("!I9B`H)'II<"!A;F0@;7D@)&UE
M=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PH@("`@("`@("`@
M("`D;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*("`@("`@("`@("`@)&UE=&$@
M/7X@<R]>7%,N*B\O;7,["B`@("`@("`@("`@("1M971A(#U^("]>("`H6UXZ
M72LI.B`H+BLI)"]M9SL*("`@("`@("!]"B`@("!].PH*("`@(",@3W!E;B!I
M;G!U="!A;F0@;W5T<'5T(&9I;&5S('M[>PH@("`@;&]C86P@)"\@/2!<-#L*
M"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!005(L("<\
M)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*("`@("`@("!B:6YM;V1E*%!!
M4BD["B`@("`@("`@9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE
M<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PH@("`@?0H*("`@($-R96%T95!A
M=&@H)&]U="D@.PH@("`@"B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`H@
M("`@("`@("1O=70L"B`@("`@("`@24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/
M.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*("`@
M("`@("`P-S<W+`H@("`@*2!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D[
M"@H@("`@)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z
M('5N9&5F.PH@("`@<V5E:R!?1D@L(#`L(#`["B`@("!M>2`D;&]A9&5R(#T@
M<V-A;&%R(#Q?1D@^.PH@("`@:68@*"$D14Y6>U!!4E]615)"051)37T@86YD
M("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["B`@("`@("`@<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("`@("`@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*("`@('T*("`@
M(&9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*("`@("`@("!M
M>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PH@("`@("`@("1V86P@/2!E
M=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PH@("`@("`@(&UY("1M86=I
M8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*("`@("`@("!M
M>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PH@("`@("`@
M("1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*("`@("`@("`@("`@)&UA9VEC
M("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI
M"B`@("`@("`@?65G.PH@("`@?0H@("`@)&9H+3YP<FEN="@D;&]A9&5R*3L*
M("`@("0O(#T@=6YD968["B`@("`C('U]?0H*("`@(",@5W)I=&4@8G5N9&QE
M9"!M;V1U;&5S('M[>PH@("`@:68@*"1B=6YD;&4I('L*("`@("`@("!R97%U
M:7)E(%!!4CHZ2&5A=GD["B`@("`@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PH@("`@("`@(&EN:71?:6YC*"D["@H@("`@("`@(')E<75I
M<F5?;6]D=6QE<R@I.PH*("`@("`@("!M>2!`:6YC(#T@<V]R="!["B`@("`@
M("`@("`@(&QE;F=T:"@D8BD@/#T^(&QE;F=T:"@D82D*("`@("`@("!](&=R
M97`@>PH@("`@("`@("`@("`A+T)31%!!3B\*("`@("`@("!](&=R97`@>PH@
M("`@("`@("`@("`H)&)U;F1L92!N92`G<VET92<I(&]R"B`@("`@("`@("`@
M("@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B`@("`@
M("`@("`@("`D7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PH@
M("`@("`@('T@0$E.0SL*"B`@("`@("`@(R!&:6QE(&5X:7-T<R!T97-T(&%D
M9&5D('1O(&9I>"!25"`C-#$W.3`Z"B`@("`@("`@(R!&=6YN>2P@;F]N+65X
M:7-T:6YG(&5N=')Y(&EN(%\\+BXN+F%U=&\O0V]M<')E<W,O4F%W+UIL:6(O
M875T;W-P;&ET+FEX+@H@("`@("`@(",@5&AI<R!I<R!A(&)A;F0M86ED(&9I
M>"!W:71H(&YO(&1E97!E<B!G<F%S<"!O9B!T:&4@:7-S=64N"B`@("`@("`@
M(R!3;VUE8F]D>2!P;&5A<V4@9V\@=&AR;W5G:"!T:&4@<&%I;B!O9B!U;F1E
M<G-T86YD:6YG('=H870G<R!H87!P96YI;F<L"B`@("`@("`@(R!)(&9A:6QE
M9"X@+2T@4W1E9F9E;@H@("`@("`@(&UY("5F:6QE<SL*("`@("`@("`O7E\\
M*"XK*20O(&%N9"`M92`D,2!A;F0@)&9I;&5S>R0Q?2LK(&9O<B!K97ES("4Z
M.CL*("`@("`@("`D9FEL97-[)%]]*RL@9F]R('9A;'5E<R`E24Y#.PH*("`@
M("`@("!M>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*
M("`@("`@("!M>2`E=W)I='1E;CL*"B`@("`@("`@9F]R96%C:"`H<V]R="!K
M97ES("5F:6QE<RD@>PH@("`@("`@("`@("!M>2`H)&YA;64L("1F:6QE*3L*
M"B`@("`@("`@("`@(&9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PH@("`@("`@
M("`@("`@("`@:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M7WTI('L*("`@("`@("`@("`@("`@("`@("`D9FEL92`]("1?.PH@("`@("`@
M("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!E;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2![
M"B`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)#$L("0R
M*3L*("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ
M6UY#8UTI7%HA*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&UY("1R968@
M/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@96QS:68@*"UF("(D9&ER+R0Q(BD@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@B
M)&1I<B\D,2(L("0Q*3L*("`@("`@("`@("`@("`@("`@("`@("`@;&%S=#L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@(&YE>'0@=6YL97-S(&1E9FEN960@)&YA
M;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*("`@("`@("`@("`@;F5X
M="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%
M)"\["B`@("`@("`@("`@(&]U=',H(&IO:6X@(B(L"B`@("`@("`@("`@("`@
M("!Q<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@
M)&9I;&4L"B`@("`@("`@("`@("`@("!Q<2@B+BXN*0H@("`@("`@("`@("`I
M.PH*("`@("`@("`@("`@;7D@)&-O;G1E;G0["B`@("`@("`@("`@(&EF("AR
M968H)&9I;&4I*2!["B`@("`@("`@("`@("`@("`D8V]N=&5N="`]("1F:6QE
M+3Y[8G5F?3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@
M("`@("`@("`@("`@(&]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A
M;B=T(&]P96X@)&9I;&4Z("0A(CL*("`@("`@("`@("`@("`@(&)I;FUO9&4H
M1DE,12D["B`@("`@("`@("`@("`@("`D8V]N=&5N="`](#Q&24Q%/CL*("`@
M("`@("`@("`@("`@(&-L;W-E($9)3$4["@H@("`@("`@("`@("`@("`@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4I"B`@("`@("`@("`@("`@("`@("`@:68@(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PH*("`@("`@("`@
M("`@("`@(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH
M7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!O=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PH@("`@("`@
M("`@("`D9F@M/G!R:6YT*")&24Q%(BD["B`@("`@("`@("`@("1F:"T^<')I
M;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B`@("`@("`@("`@
M("1F:"T^<')I;G0H<W!R:6YT9B@*("`@("`@("`@("`@("`@("(E,#AX+R5S
M(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M
M90H@("`@("`@("`@("`I*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K
M*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PH@("`@("`@("`@("`D9F@M/G!R
M:6YT*"1C;VYT96YT*3L*("`@("`@("!]"B`@("!]"B`@("`C('U]?0H*("`@
M(",@3F]W('=R:71E(&]U="!T:&4@4$%2(&%N9"!M86=I8R!S=')I;F=S('M[
M>PH@("`@)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PH*
M("`@("1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*
M("`@(&EF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O
M=70I*5LY72D@>PH@("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$
M:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@
M('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q
M+3YN97<@?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z
M.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`C(%=O<FMA<F]U
M;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@
M("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D52
M4TE/3B!]('Q\(#`["B`@("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS
M."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@("`D
M8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PH@("`@("`@('T*
M("`@("`@("!E;'-E('L*("`@("`@("`@("`@:68@*"1C='@@86YD(&]P96XH
M;7D@)&9H+"`B/"1O=70B*2D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D
M9F@I.PH@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@
M("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG
M97-T(#H@)&UT:6UE.PH@("`@?0H@("`@)&-A8VAE7VYA;64@+CT@(EPP(B!X
M("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B`@("`D8V%C:&5?;F%M92`N
M/2`B0T%#2$4B.PH@("`@)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B`@("`D
M9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E
M<BDI*3L*("`@("1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*("`@("1F:"T^
M8VQO<V4["B`@("!C:&UO9"`P-S4U+"`D;W5T.PH@("`@(R!]?7T*"B`@("!E
M>&ET.PI]"B,@?7U]"@HC(%!R97!A<F4@)'!R;V=N86UE(&EN=&\@4$%2(&9I
M;&4@8V%C:&4@>WM["GL*("`@(&QA<W0@=6YL97-S(&1E9FEN960@)'-T87)T
M7W!O<SL*"B`@("!?9FEX7W!R;V=N86UE*"D["@H@("`@(R!.;W<@;&]A9"!T
M:&4@4$%2(&9I;&4@86YD('!U="!I="!I;G1O(%!!4CHZ3&EB0V%C:&4@>WM[
M"B`@("!R97%U:7)E(%!!4CL*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*"@H@("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG
M?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q
M=6ER92!&:6QE.CI&:6YD.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ6FEP
M.PH@("`@?0H@("`@;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*("`@("1F:"T^9F1O<&5N*&9I;&5N
M;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*("`@("1Z:7`M/G)E861&
M<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*"B`@("!P=7-H($!005(Z.DQI
M8D-A8VAE+"`D>FEP.PH@("`@)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]
M("1Z:7`["@H@("`@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*("`@(&]U
M=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PH*
M("`@(&EF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E
M('-E="!A="!T:&ES('!O:6YT(0H@("`@("`@(&9O<F5A8V@@;7D@)&UE;6)E
M<B`H("1Z:7`M/FUE;6)E<G,@*2!["B`@("`@("`@("`@(&YE>'0@:68@)&UE
M;6)E<BT^:7-$:7)E8W1O<GD["B`@("`@("`@("`@(&UY("1M96UB97)?;F%M
M92`]("1M96UB97(M/F9I;&5.86UE.PH@("`@("`@("`@("!N97AT('5N;&5S
M<R`D;65M8F5R7VYA;64@/7X@;7L*("`@("`@("`@("`@("`@(%X*("`@("`@
M("`@("`@("`@("\_<VAL:6(O"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG
M.CI#;VYF:6=[=F5R<VEO;GTO*3\*("`@("`@("`@("`@("`@("@_.B1#;VYF
M:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\*("`@("`@("`@("`@("`@("A;7B]=
M*RD*("`@("`@("`@("`@("`@("0*("`@("`@("`@("`@?7@["B`@("`@("`@
M("`@(&UY("1E>'1R86-T7VYA;64@/2`D,3L*("`@("`@("`@("`@;7D@)&1E
M<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL
M("1E>'1R86-T7VYA;64I.PH@("`@("`@("`@("!I9B`H+68@)&1E<W1?;F%M
M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PH@
M("`@("`@("`@("`@("`@;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE
M(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&]U=',H<7$H
M17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*
M("`@("`@("`@("`@("`@("1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D
M9&5S=%]N86UE*3L*("`@("`@("`@("`@("`@(&-H;6]D*#`U-34L("1D97-T
M7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("!]"B`@("`C('U]?0I]"B,@?7U]"@HC($EF('1H97)E)W,@;F\@
M;6%I;BYP;"!T;R!R=6XL('-H;W<@=7-A9V4@>WM["G5N;&5S<R`H)%!!4CHZ
M3&EB0V%C:&5[)'!R;V=N86UE?2D@>PH@("`@9&EE(#P\("(N(B!U;FQE<W,@
M0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-
M;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*("`@("`@("0P
M(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*("`@("1%3E9[4$%2
M7U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]
M"B,@?7U]"@IS=6(@0W)E871E4&%T:"!["B`@("!M>2`H)&YA;64I(#T@0%\[
M"B`@("`*("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@("!M>2`H)&)A
M<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A
M<G-E*"1N86UE+"`H)UPN+BHG*2D["B`@("`*("`@(')E<75I<F4@1FEL93HZ
M4&%T:#L*("`@(`H@("`@1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE
M<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0H*<W5B
M(')E<75I<F5?;6]D=6QE<R!["B`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@
M/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH*("`@(')E<75I<F4@
M;&EB.PH@("`@<F5Q=6ER92!$>6YA3&]A9&5R.PH@("`@<F5Q=6ER92!I;G1E
M9V5R.PH@("`@<F5Q=6ER92!S=')I8W0["B`@("!R97%U:7)E('=A<FYI;F=S
M.PH@("`@<F5Q=6ER92!V87)S.PH@("`@<F5Q=6ER92!#87)P.PH@("`@<F5Q
M=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@17)R;F\["B`@("!R97%U
M:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(["B`@
M("!R97%U:7)E($9C;G1L.PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@
M<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@<F5Q=6ER92!84TQO861E<CL*("`@
M(')E<75I<F4@0V]N9FEG.PH@("`@<F5Q=6ER92!)3SHZ2&%N9&QE.PH@("`@
M<F5Q=6ER92!)3SHZ1FEL93L*("`@(')E<75I<F4@0V]M<')E<W,Z.EIL:6([
M"B`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@(')E<75I<F4@4$%2.PH@
M("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!005(Z.D1I<W0[
M"B`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@(')E<75I
M<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*("`@(')E<75I<F4@871T
M<FEB=71E<SL*("`@(&5V86P@>R!R97%U:7)E($-W9"!].PH@("`@979A;"![
M(')E<75I<F4@5VEN,S(@?3L*("`@(&5V86P@>R!R97%U:7)E(%-C86QA<CHZ
M571I;"!].PH@("`@979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U
M<G-T('T["B`@("!E=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P
M='5R92!].PH@("`@979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E
M<FQ)3SHZ<V-A;&%R('T["GT*"B,@5&AE($,@=F5R<VEO;B!O9B!T:&ES(&-O
M9&4@87!P96%R<R!I;B!M>6QD<B]M:W1M<&1I<BYC"B,@5&AI<R!C;V1E(&%L
M<V\@;&EV97,@:6X@4$%2.CI3971U<%1E;7`@87,@<V5T7W!A<E]T96UP7V5N
M=B$*<W5B(%]S971?<&%R7W1E;7`@>PH@("`@:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PH@("`@
M("`@("1P87)?=&5M<"`]("0Q.PH@("`@("`@(')E='5R;CL*("`@('T*"B`@
M("!F;W)E86-H(&UY("1P871H("@*("`@("`@("`H;6%P("1%3E9[)%]]+"!Q
M=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*("`@
M("`@("!Q=R@@0SI<7%1%35`@+W1M<"`N("D*("`@("D@>PH@("`@("`@(&YE
M>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D
M<&%T:#L*("`@("`@("!M>2`D=7-E<FYA;64["B`@("`@("`@;7D@)'!W=6ED
M.PH@("`@("`@(",@9&]E<R!N;W0@=V]R:R!E=F5R>7=H97)E.@H@("`@("`@
M(&5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[
M?3L*"B`@("`@("`@:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I
M('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64[
M"B`@("`@("`@?0H@("`@("`@(&5L<VEF("AD969I;F5D("1P=W5I9"D@>PH@
M("`@("`@("`@("`D=7-E<FYA;64@/2`D<'=U:60["B`@("`@("`@?0H@("`@
M("`@(&5L<V4@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`D14Y6>U5315).
M04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PH@("`@("`@('T*("`@
M("`@("`D=7-E<FYA;64@/7X@<R]<5R]?+V<["@H@("`@("`@(&UY("1S=&UP
M9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+21U<V5R;F%M92(["B`@
M("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@:68@*"$D14Y6
M>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI
M6SE=*2!["B`@("`@("`@("`@(&]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA
M;64I.PH@("`@("`@("`@("!S965K("1F:"P@+3$X+"`R.PH@("`@("`@("`@
M("!S>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*("`@("`@("`@("`@:68@*"1B
M=68@97$@(EPP0T%#2$4B*2!["B`@("`@("`@("`@("`@("!S965K("1F:"P@
M+34X+"`R.PH@("`@("`@("`@("`@("`@<WES<F5A9"`D9F@L("1B=68L(#0Q
M.PH@("`@("`@("`@("`@("`@)&)U9B`]?B!S+UPP+R]G.PH@("`@("`@("`@
M("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D
M8G5F.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@
M("`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@("`@("`@("!\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^
M;F5W('T*("`@("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$
M:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`@("`@
M("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@
M86YD(#4N,SD*("`@("`@("`@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V
M86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@("`@
M("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S
M:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@("`@("`@("`@("1C='@M/F%D
M9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@
M("`@("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D
M8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*
M("`@("`@("`@("`@)$5.5GM005)?0TQ%04Y](#T@,3L*("`@("`@("`@("`@
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PH@("`@("`@
M('T*"B`@("`@("`@)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*("`@("`@
M("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!L87-T.PH@("`@?0H*
M("`@("1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6
M>U!!4E]414U0?2`]?B`O*"XK*2\["GT*"G-U8B!?=&5M<&9I;&4@>PH@("`@
M;7D@*"1E>'0L("1C<F,I(#T@0%\["B`@("!M>2`H)&9H+"`D9FEL96YA;64I
M.PH*("`@("1F:6QE;F%M92`]("(D<&%R7W1E;7`O)&-R8R1E>'0B.PH*("`@
M(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@("`@("!U;FQI;FL@)&9I;&5N
M86UE(&EF("UE("1F:6QE;F%M93L*("`@("`@("!P=7-H($!T;7!F:6QE+"`D
M9FEL96YA;64["B`@("!]"B`@("!E;'-E('L*("`@("`@("!R971U<FX@*'5N
M9&5F+"`D9FEL96YA;64I(&EF("@M<B`D9FEL96YA;64I.PH@("`@?0H*("`@
M(&]P96X@)&9H+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("!B:6YM
M;V1E*"1F:"D["B`@("!R971U<FXH)&9H+"`D9FEL96YA;64I.PI]"@HC('-A
M;64@8V]D92!L:79E<R!I;B!005(Z.E-E='5P4')O9VYA;64Z.G-E=%]P<F]G
M;F%M90IS=6(@7W-E=%]P<F]G;F%M92!["B`@("!I9B`H9&5F:6YE9"`D14Y6
M>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK
M*2\I('L*("`@("`@("`D<')O9VYA;64@/2`D,3L*("`@('T*"B`@("`D<')O
M9VYA;64@?'P]("0P.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD
M97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PH@("`@("`@
M("1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA
M;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*("`@('T*"B`@("!I9B`H(21%
M3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@/CT@,"D@>PH@("`@("`@(&EF("AO<&5N(&UY("1F:"P@)SPG
M+"`D<')O9VYA;64I('L*("`@("`@("`@("`@<F5T=7)N(&EF("US("1F:#L*
M("`@("`@("!]"B`@("`@("`@:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E
M>&5](BD@>PH@("`@("`@("`@("`D<')O9VYA;64@+CT@)$-O;F9I9WM?97AE
M?3L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*("`@('T*"B`@("!F
M;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O
M+"`D14Y6>U!!5$A]*2!["B`@("`@("`@;F5X="!I9B!E>&ES=',@)$5.5GM0
M05)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B`@("`@("`@
M)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B`@("`@("`@*"@D
M<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF
M:6=[7V5X97TB*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL*("`@("`@("`H
M*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL
M(&QA<W0I"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(CL*("`@('T*?0H*<W5B(%]F:7A?<')O9VYA;64@>PH@("`@
M)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*("`@(&EF
M("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B`@
M("`@("`@)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B
M.PH@("`@?0H*("`@(",@6%A8("T@:&%C:R!T;R!M86ME(%!71"!W;W)K"B`@
M("!M>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T
M8W=D*"D*("`@("`@("`@("`@("`@(#H@*"AD969I;F5D("97:6XS,CHZ1V5T
M0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*("`@(&-H;VUP*"1P
M=V0I.PH@("`@)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D
M96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["@H@("`@)$5.5GM005)?
M4%)/1TY!345](#T@)'!R;V=N86UE.PI]"@IS=6(@7W!A<E]I;FET7V5N=B![
M"B`@("!I9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["B`@
M("`@("`@<F5T=7)N.PH@("`@?2!E;'-E('L*("`@("`@("`D14Y6>U!!4E])
M3DE424%,25I%1'T@/2`R.PH@("`@?0H*("`@(&9O<B`H<7<H(%-005=.140@
M5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I
M("D@>PH@("`@("`@(&1E;&5T92`D14Y6>R=005)?)RXD7WT["B`@("!]"B`@
M("!F;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B`@("`@
M("`@)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I
M9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*("`@('T*"B`@("!M
M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@
M("`@(CL*"B`@("!I9B`H)$5.5GM005)?5$5-4'TI('L*("`@("`@("!D96QE
M=&4@)$5.5GM005)?0TQ%04Y].PH@("`@?0H@("`@96QS:68@*"%E>&ES=',@
M)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PH@("`@("`@(&UY("1V86QU92`]
M('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B`@
M("`@("`@)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%2
M7T-,14%./2A<4RLI+SL*("`@('T*?0H*<W5B(&]U=',@>PH@("`@<F5T=7)N
M(&EF("1Q=6EE=#L*("`@(&EF("@D;&]G9F@I('L*("`@("`@("!P<FEN="`D
M;&]G9F@@(D!?7&XB.PH@("`@?0H@("`@96QS92!["B`@("`@("`@<')I;G0@
M(D!?7&XB.PH@("`@?0I]"@IS=6(@:6YI=%]I;F,@>PH@("`@<F5Q=6ER92!#
M;VYF:6<["B`@("!P=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF
M:6<Z.D-O;F9I9WLD7WTL('%W*`H@("`@("`@(&%R8VAL:6)E>'`@<')I=FQI
M8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"B`@("`@("`@=F5N9&]R87)C
M:&5X<"!V96YD;W)L:6)E>'`*("`@("D["GT*"B,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(PHC(%1H92!M86EN('!A8VMA9V4@9F]R('-C<FEP="!E>&5C
M=71I;VX*"G!A8VMA9V4@;6%I;CL*"G)E<75I<F4@4$%2.PIU;G-H:69T($!)
M3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*
M"F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G
M;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*("`@('5N;&5S
M<R`M92`D<')O9VYA;64["@ID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I
M(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D
M0#L*"GT["@HD.CI?7T524D]2(#T@)$`@:68@)$`["GT*"D-/4D4Z.F5X:70H
M)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*
M9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*"C$["@HC;&EN92`Q,#$Q
M"@I?7T5.1%]?"@````!'0T,Z("A58G5N='4O3&EN87)O(#0N-BXR+3=U8G5N
M='4Q*2`T+C8N,@!'0T,Z("A58G5N='4O3&EN87)O(#0N-BXR+35U8G5N='4Q
M*2`T+C8N,@``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T
M92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU
M+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`+G)E;"YP;'0`+FEN
M:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M
M90`N8W1O<G,`+F1T;W)S`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9V]T+G!L=``N
M9&%T80`N8G-S`"YC;VUM96YT````````````````````````````````````
M```````````````````+`````0````(```!4@00(5`$``!,`````````````
M``$`````````$P````<````"````:($$"&@!```@```````````````$````
M`````"$````'`````@```(B!!`B(`0``)```````````````!``````````T
M````]O__;P(```"L@00(K`$``%@!```%``````````0````$````/@````L`
M```"````!(,$"`0#``"0!@``!@````$````$````$````$8````#`````@``
M`)2)!`B4"0``_`0``````````````0````````!.````____;P(```"0C@0(
MD`X``-(````%``````````(````"````6P```/[__V\"````9(\$"&0/``"@
M````!@````(````$`````````&H````)`````@````20!`@$$```,`````4`
M````````!`````@```!S````"0````(````TD`0(-!```"@"```%````#```
M``0````(````?`````$````&````7)($"%P2```N```````````````$````
M`````'<````!````!@```)"2!`B0$@``8`0`````````````$`````0```""
M`````0````8```#PE@0(\!8``#Q'`````````````!``````````B`````$`
M```&````+-X$""Q>```:```````````````$`````````(X````!`````@``
M`$C>!`A(7@``2`,`````````````"`````````"6`````0````(```"0X00(
MD&$``/P```````````````0`````````I`````$````"````C.($"(QB```X
M!0`````````````$`````````*X````!`````P````3_!`@$;P``"```````
M````````!`````````"U`````0````,````,_P0(#&\```@`````````````
M``0`````````O`````$````#````%/\$"!1O```$```````````````$````
M`````,$````&`````P```!C_!`@8;P``V`````8`````````!`````@```#*
M`````0````,```#P_P0(\&\```0```````````````0````$````SP````$`
M```#````]/\$"/1O```@`0`````````````$````!````-@````!`````P``
M`"`!!0@@<0``Y%L`````````````(`````````#>````"`````,````@704(
M!,T``'`0`````````````"``````````XP````$````P``````````3-``!4
M```````````````!`````0````$````#``````````````!8S0``[```````
.`````````0``````````
